#include "inland_config.h"
! ---------------------------------------------------------------------
subroutine existence
! ---------------------------------------------------------------------
!
! this routine determines which plant functional types (pft's) are allowed
! to exist in each gridcell, based on a simple set of climatic criteria
!
! the logic here is based on the biome3 model of haxeltine and prentice
!
! plant functional types:
!
! 1)  tropical broadleaf evergreen trees
! 2)  tropical broadleaf drought-deciduous trees
! 3)  warm-temperate broadleaf evergreen trees
! 4)  temperate conifer evergreen trees
! 5)  temperate broadleaf cold-deciduous trees
! 6)  boreal conifer evergreen trees
! 7)  boreal broadleaf cold-deciduous trees
! 8)  boreal conifer cold-deciduous trees
! 9)  evergreen shrubs
! 10) deciduous shrubs
! 11) warm (c4) grasses
! 12) cool (c3) grasses

      use inland_ibispar
      use inland_compft
      use inland_comveg

      implicit none
!-----------------------------------------------------------------------
!
! local variables
!
      integer i
!
      do 100 i = lbeg, lend

! determine which plant types can exist in a given gridcell
         exist(i,1)  = 0.
         exist(i,2)  = 0.
         exist(i,3)  = 0.
         exist(i,4)  = 0.
         exist(i,5)  = 0.
         exist(i,6)  = 0.
         exist(i,7)  = 0.
         exist(i,8)  = 0.
         exist(i,9)  = 0.
         exist(i,10) = 0.
         exist(i,11) = 0.
         exist(i,12) = 0.
!
!*** DTP 2001/06/07: Modified version of above code reads in PFT
! existence criteria from external parameter file "params.veg"
!    These are copied here for reference.... 
!------------------------------------------------------------------
!  TminL    TminU    Twarm    GDD    PFT
!------------------------------------------------------------------
!    0.0   9999.0   9999.0   9999  !   1
!    0.0   9999.0   9999.0   9999  !   2
!  -10.0      0.0   9999.0   9999  !   3
!  -45.0      0.0   9999.0   1200  !   4
!  -45.0      0.0   9999.0   1200  !   5
!  -57.5    -45.0   9999.0    350  !   6
!  -57.5    -45.0   9999.0    350  !   7
! 9999.0    -45.0   9999.0    350  !   8
! 9999.0   9999.0   9999.0    100  !   9
! 9999.0   9999.0   9999.0    100  !  10
! 9999.0   9999.0     22.0    100  !  11
! 9999.0   9999.0   9999.0    100  !  12
!------------------------------------------------------------------
!
! 1) tropical broadleaf evergreen trees
!
!  - tcmin > 0.0
         if (tcmin(i).gt.TminL(1)) exist(i,1) = 1.0

! 2) tropical broadleaf drought-deciduous trees
!
!  - tcmin > 0.0
         if (tcmin(i).gt.TminL(2)) exist(i,2) = 1.0

! 3) warm-temperate broadleaf evergreen trees
!
!  - tcmin <   0.0 and
!  - tcmin > -10.0
         if ((tcmin(i).lt.TminU(3)).and.(tcmin(i).gt.TminL(3))) exist(i,3) = 1.0

! 4) temperate conifer evergreen trees
!
!  - tcmin <    0.0 and
!  - tcmin >  -45.0 and
!  - gdd5  > 1200.0
         if ((tcmin(i).lt.TminU(4)).and.(tcmin(i).gt.TminL(4)).and. &
             (gdd5(i).gt.GDD(4))) exist(i,4) = 1.0

! 5) temperate broadleaf cold-deciduous trees
!
!  - tcmin <    0.0 and
!  - tcmin >  -45.0 and
!  - gdd5  > 1200.0
         if ((tcmin(i).lt.TminU(5)).and.(tcmin(i).gt.TminL(5)).and. &
             (gdd5(i).gt.GDD(5))) exist(i,5) = 1.0

! 6) boreal conifer evergreen trees
!
!  - tcmin <  -45.0 or gdd5 < 1200.0, and
!  - tcmin >  -57.5 and
!  - gdd5  >  350.0
         if (((tcmin(i).lt.TminU(6)).or.(gdd5(i).lt.GDD(4))).and. &
              (tcmin(i).gt.TminL(6)).and.(gdd5(i).gt.GDD(6))) exist(i,6) = 1.0

! 7) boreal broadleaf cold-deciduous trees
!
!  - tcmin <  -45.0 or gdd5 < 1200.0, and
!  - tcmin >  -57.5 and
!  - gdd5  >  350.0
         if (((tcmin(i).lt.TminU(7)).or.(gdd5(i).lt.GDD(5))).and. &
             (tcmin(i).gt.TminL(7)).and.(gdd5(i).gt.GDD(7))) exist(i,7) = 1.0

! 8) boreal conifer cold-deciduous trees
!
!  - tcmin <  -45.0 or gdd5 < 1200.0, and
!  - gdd5  >  350.0
         if (((tcmin(i).lt.TminU(8)).or.(gdd5(i).lt.GDD(4))).and. &
              (gdd5(i).gt.GDD(8))) exist(i,8) = 1.0

! 9) evergreen shrubs
!
!  - gdd0 > 100.0
         if (gdd0(i).gt.GDD(9)) exist(i,9) = 1.0

! 10) deciduous shrubs
!
!  - gdd0 > 100.0
         if (gdd0(i).gt.GDD(10)) exist(i,10) = 1.0

! 11) warm (c4) grasses
!
!  - tw   >  22.0 and
!  - gdd0 > 100.0
         if ((tw(i).gt.Twarm(11)).and.(gdd0(i).gt.GDD(11))) exist(i,11) = 1.0

! 12) cool (c3) grasses
!
!  - gdd0 > 100.0
         if (gdd0(i).gt.GDD(12)) exist(i,12) = 1.0
100   continue
      return
end subroutine existence
