#include "inland_config.h"
#ifndef PCMIBIS
subroutine ibis_interface(iradsw)
#else
subroutine ibis_interface(iradsw, qoverxy, qdraixy)
#endif
!-----------------------------------------------------------------------
!
! Call land surface model. This is interface code. It is
! the time-stepping interface between the land surface model 
! and CCM. It gets required variables from CCM common blocks. 
! It returns required variables to CCM common blocks. It changes 
! units as needed. A similar interface is needed regardless of what 
! land surface model is used.
!
!-----------------------------------------------------------------------
!------------------------ code history ---------------------------------
! standardized:      J. Truesdale, Feb. 1996
! reviewed:          G. Bonan, Feb. 1996
! reviewed:          A. Hahmann, Jun. 1996
!-----------------------------------------------------------------------

#ifndef PCMIBIS
# if (defined STAND_ALONE || defined COUP_CSM)
# else
      use pmgrid
      use comsrf
# endif
#endif
      use comlsmh
#ifdef CAMIBIS
# if (defined STAND_ALONE || defined COUP_CSM)
      use modmain
      use shr_sys_mod, only : shr_sys_flush
# else
      use ghg_surfvals, only: co2vmr
      use atm_lndMod
# endif
#endif
#ifdef ATMCO2
      use atmco2, only : &
         atmco2_DebugPrint => DebugPrint, &
         atmco2_GetCO2Index => GetCO2Index, &
         atmco2_GetAtmCO2 => GetAtmCO2, &
         atmco2_UseProgCO2 => UsePrognosticCO2, &
         atmco2_UseProgCO2_3D => UsePrognosticCO2_3D, &
         atmco2_UseProgCO2_Lnd => UsePrognosticCO2_Lnd, &
         atmco2_SetLandExchange => SetLandExchange, &
         atmco2_SetLandFlux => SetLandFlux
#endif
  
      implicit none
!--------------------------------Commons--------------------------------
#ifdef PCMIBIS
#include "pmgrid.h"
#include "pagrid.h"
#include "comsrf.h"
#include "comhed.h"
#include <crdcon.h>
#include <comhyb.h>
#endif
#ifndef CAMIBIS
#include <comtim.h>
#include <comvmr.h>
#endif
!-------------------------------Arguments-------------------------------
!
! Input arguments
!
      integer iradsw    ! Shortwave frequency
#ifdef PCMIBIS
      real*8 qoverxy(plond,beglat:endlat)    ! Runoff
      real*8 qdraixy(plond,beglat:endlat)    ! Drainage
#endif
!
!----------------------------Local variables----------------------------
      integer i,j,m             ! Loop index
      logical doalb             ! Is next timestep a radiation time?
      real*8 prcxy(plond,beglat:endlat)    ! Convective precipitation (mm h2o/s)
      real*8 prlxy(plond,beglat:endlat)    ! Large-scale precipitation (mm h2o/s)
      real*8 land_atm_exchange   ! units of moles, positive to atmosphere
      real*8 co2_conc
      integer co2_idx
#ifdef CAMIBIS
      integer nstep
      real*8 dtime
#endif
      integer restart_written
      integer runit
      data runit / 9 /

!
#ifdef CAMIBIS
      nstep = nstepz
      dtime = dtimez
#endif
      doalb = (iradsw .eq. 1) .or. 
     $     (mod(nstep,iradsw) .eq. 0 .and. nstep .ne. 0)
!
      do j=beglat,endlat
         do i=1,plon
            prcxy(i,j) = precc(i,j)*1000.           !m/s -> mm/s
            prlxy(i,j) = precl(i,j)*1000.           !m/s -> mm/s
         end do
      end do
!

#ifdef ATMCO2
!       Set the atmospheric CO2 based on whether we are using explicit
!       emissions (see atmco2).  Note that atmco2_GetAtmCO2 returns
!       ppmv, while co2vmr is a volume mixing ratio, and IBIS wants a
!       volume mixing ratio.

!       The "normal" concentration, [[co2vmr_ramp]], has be saved for
!       use in submodels that have the prognostic CO2 switched off.

      if ( atmco2_UseProgCO2_Lnd() ) then
         co2_conc = atmco2_GetAtmCO2() * 1.0e-6
      else
         co2_conc = co2vmr_ramp
      endif

      if ( atmco2_UseProgCO2() ) then
         call atmco2_DebugPrint( 'CO2 seen by ibis = ', co2_conc )
      endif
#endif

#ifdef PCMIBIS
      call ibisdrv(pbot    ,psm1    ,                   &
     		   ubot    ,vbot    ,tbot    ,qbot    , & 
     		   flwds(1,beglat)  ,prcxy   ,prlxy   , &
     		   sols(1,beglat)   ,soll(1,beglat)   , &
     		   solsd(1,beglat)  ,solld(1,beglat)  , &
     		   doalb   ,nstep   ,                   &
     		   ndbase  ,nsbase  ,nbdate  ,nbsec   , &
     		   dtime   ,ts(1,beglat)     ,shf     , &
     		   lhf	  ,cflx    ,wsx     ,           &
     		   wsy	  ,tref    ,asdir(1,beglat)  ,  &
     		   asdif(1,beglat)  ,aldir(1,beglat)  , &
# ifdef ATMCO2
                   land_atm_exchange,                   &
# endif
     		   aldif(1,beglat)  ,lwup(1,beglat)   ,h2osnoxy, &
     		   qoverxy ,qdraixy , &
     		   co2_conc  )
#else
# ifdef CAMIBIS
      call ibisdrv(pbot    ,psm1d   ,
# else
      call ibisdrv(pbot    ,psm1    , &
# endif
     		   ubot    ,vbot    ,tbot    ,qbot    , &
     		   flwds   ,prcxy   ,prlxy   , &
     		   sols    ,soll    , &
     		   solsd   ,solld   , &
     		   doalb   ,nstep   , &
# ifndef CAMIBIS
                   ndbase  ,nsbase  ,nbdate  ,nbsec   , &
# endif
     		   dtime   ,ts	   ,shf     , &
     		   lhf	  ,cflx    ,wsx     , &
     		   wsy	  ,tref    ,asdir   , &
     		   asdif   ,aldir   ,	      &
     		   aldif   ,lwup    ,h2osnoxy, &
# ifdef COUP_CSM
                   qrunoff ,qref    ,swab    , &
# endif
# if (defined STAND_ALONE || defined COUP_CSM)
                   restart_written  , &
# endif
                   co2vmr)
#endif
!
#ifdef ATMCO2
      if ( atmco2_UseProgCO2() ) then
!         Give the global carbon exchange to the atmosphere.  Units are
!         mol/timestep, positive to the atmosphere.
         call atmco2_SetLandExchange( land_atm_exchange )

!         After IBIS is called, cflx(:,co2_idx,:) should contain the
!         land carbon flux (positive to the atmosphere) in
!         kg CO2 / m^2 / sec.  This is to be used as a 2D flux for a co2
!         tracer.  (This will ultimately just go back into cflx, but
!         this is for consistency with the treatment of ocean fluxes.)

         if ( atmco2_UseProgCO2_3D() ) then
            co2_idx = atmco2_GetCO2Index()
            call atmco2_SetLandFlux( cflx(1:plon,co2_idx,:) )
         endif
      endif
#endif
#if (defined STAND_ALONE || defined COUP_CSM)
      if (restart_written .eq. 1) then
! myidd accessed through modmain
         if (myidd .eq. 0) then
            open(unit=runit,file='ibis_timemgr_control',
     $         form='unformatted',access='sequential')
            call timemgr_write_restart(runit)
            close(runit)
         endif
      endif
#endif
!
! Over land Set ws and sn for land points
! Over ocean, set BATS output fields to undefined if not on land
!
#ifndef CAMIBIS
      do m=1,plevmx         
         do j=beglat,endlat
            do i=1,plon
               if (oro(i,j).eq.1.) tssub(i,m,j) = ts(i,j)
            end do
         end do
      end do
#endif
!     
      do j=beglat,endlat
         do i=1,plon
#ifdef CAMIBIS
! oro is the land fraction
            if (oro(i,j).gt.0.) then
#else
! oro is a land/ocean/sea ice flag
            if (oro(i,j).eq.1.) then
#endif
               snowh(i,j) = h2osnoxy(i,j)/1000.
            end if
         end do
      end do
!
      return
end subroutine ibis_interface

