#include "inland_config.h"
subroutine ibiszen (calday, lon, lat, cosz, kpti, kptj)
!-----------------------------------------------------------------------
!
! Computes the cosine of the solar zenith angle for lsm 
! calculations
!-----------------------------------------------------------------------
      use ibispar

      implicit none
!------------------------------- Notes ---------------------------------
! cosine solar zenith angle from:
!    o day (1.x to 365.x), where x=0 (e.g. 213.0) denotes 00:00 at greenwich
!    o latitude,  where SH = - and NH = + 
!    o longitude, where WH = - and EH = +

! the solar declination must match that used in the atmospheric model.
! for ccm2, this code matches the ccm2 cosz to within +/- 0.0001.

! this discrepancy between lsm cosz and atm cosz causes a problem.
! lsm cosz may be <= zero (sun below horizon), in which case albedos
! equal zero, but atm cosz may be > zero (sun above horizon), in which
! case atm model needs albedos. no problem if atm model has sun below 
! horizon but lsm has sun above horizon so long as atm solar fluxes 
! equal zero. a possible solution then is to reset points with sun 
! slightly below horizon to slightly above horizon. 

! in practice this error is not very large. e.g., if albedo error is 
! 0.0001 (atm cosz = 0.0001, lsm cosz = 0) absorbed solar radiation 
! error is incident flux C 0.0001. since incident flux is itself 
! multiplied by atm cosz, incident flux is small. hence, error is small.
! in fact the error is smaller than the difference between atm net solar 
! radiation at surface and lsm net solar radiation at surface, which arises
! due to the different surface radiation parameterizations.

! however, reset points as discussed above just in case atm model may
! blow up if albedos equal zero when atm cosz > 0.
!------------------------------Arguments--------------------------------
! Input arguments
!
      integer loopi           ! index of little vector in big vector
      integer kpti            ! index of 1st point of little vector
!                             ! in big lpt vector
      integer kptj            ! index of last point of little vector
!
      real*8 calday           ! calendar day + fraction (1.xx -> 365.xx)
      real*8 lon(npoi)        ! longitude (radians): + = EH
      real*8 lat(npoi)        ! latitude  (radians): + = NH
!
! Output arguments
!
      real*8 cosz(lbeg:lend)  ! cosine zenith angle 
!----------------------------Local variables----------------------------
      real*8 dayspy           ! days per year
      real*8 pi               ! pi
      real*8 theta            ! earth orbit seasonal angle in radians
      real*8 delta            ! solar declination angle  in radians
      real*8 sind             ! sine   of declination
      real*8 cosd             ! cosine of declination
      real*8 phi              ! greenwich calendar day + longitude offset
      real*8 loctim           ! local time (hour)
      real*8 hrang            ! solar hour angle, 24 hour periodicity (radians)
      integer k               ! index
      integer mcsec           ! current seconds in day (0, ..., 86400)
!-----------------------------------------------------------------------
!
      dayspy = 365.
      pi = 4.*atan(1.)
!
! solar declination: match ccm2  
!
      theta = (2.*pi*calday)/dayspy
      delta = .006918 - .399912*cos(   theta) + .070257*sin(   theta)&
                      - .006758*cos(2.*theta) + .000907*sin(2.*theta)&
                      - .002697*cos(3.*theta) + .001480*sin(3.*theta)
      sind = sin(delta)
      cosd = cos(delta)

      do k = kpti, kptj
!
! local time
!
         mcsec = (calday - int(calday)) * 86400.
         phi = calday + lon(k)/(2.*pi)
         loctim = (mcsec + (phi-calday)*86400.) / 3600.
!
! hour angle
!
         hrang = 360./24. * (loctim-12.) * pi/180.
!
! cosine solar zenith angle. reset points with sun slightly below horizon 
! to slightly above horizon, as discussed in notes.
!
        cosz(k) = sin(lat(k))*sind + cos(lat(k))*cosd*cos(hrang)
        if (cosz(k) .ge. -0.001 .and. cosz(k).le. 0.) cosz(k) = 0.001
!
      end do
!
      return
end subroutine ibiszen






