#include "inland_config.h"

#ifdef SINGLE_POINT_MODEL
#error "This subroutine should NOT be compiled for 0D IBIS model option."
#endif

! ies-io.f last update 9/9/98 Christine C. Molling, cmolling@facstaff.wisc.edu
! University of Wisconsin - Madison; Institute for Environmental Studies;
! Center for Climatic Research; Climate, People, and Environment Program
!
! You are free to change or distribute my code as long as you
! 1) acknowlege me, Christine C. Molling (cmolling@facstaff.wisc.edu)
! as the author of the original code and 
! 2) do not sell it.
! Of course if there is anything wrong with the code, or you somehow
! encounter damage to your reputation/wallet because of its use, you
! are forbidden to sue me or anyone else.
!
!     These subroutines can be used as a primary interface to the ies
! format netcdf files.  You can also use the slightly lower level functions
! found in ies.f or the low level netcdf commands (see the netcdf V3
! users guide).
!SUBROUTINE LIST:
! inifile - create a new file with dimensions and variables for
!  longitude, latitude, an optional 3rd real dimension, and time
!  Time must have units of days since a date!!!
! inifilec - create a new file with dimensions and variables for
!  longitude, latitude, a 3rd character-variable dimension, and time
!  Time must have units of days since a date!!!
! inivar - initialize a new variable
! endini - end initialization of file: sync file to disk, close file
! writevar - write a 2-, 3-, or 4-dimensional hyperslab of data
! readvar - read a 2-, 3-, or 4-dimensional hyperslab of data
!
!.....................................................................
! inifile - create a new file with dimensions and variables for
!  longitude, latitude, an optional 3rd real dimension, and time.
!  Time must have units of days since a date!!!
!.....................................................................
subroutine inifile(idies,filen,title,source,history,nlon,alons,nlat,alats, &
                   name3rd,long3rd,units3rd,axis3rd,n3rd,vals3rd,pos3rd,tunits,    &
                   calendar,ierror)
!INPUT
!     filen - character*(*) - name for new file
!     title - character*(*) - title for file
!     source - character*(*) - source for file
!     history - character*(*) - date of creation, and possibly author
!     nlon - integer - number of point along longitude direction
!     alons - real(nlon) - values of longitudes
!     nlat - integer - number of point along latitude direction
!     alats - real(nlat) - values of latitudes
!     name3rd - character*(*) - name of 3rd dimension - use 'none' if 
!      you don't want this dimension
!     long3rd - character*(*) - long name for 3rd dimension variable
!      (ignored if nam3rd='none')
!     n3rd - integer - size of 3rd dimension (ignored if name3rd='none')
!     vals3rd - real(n3rd) - values along 3rd dimension (ignored if 
!      name3rd='none')
!     pos3rd - character*(*) - if the 3rd dimension exists and refers to
!      a measured level or height, use 'up' if values increase with distance
!      above earth (as in height), or 'down' if values decrease with distance 
!      (as in pressure) (ignored if name3rd='none'). If 3rd dimension does not
!      refer to a height or level, use 'none'.
!     TODO: pos3rd variable is unused
!     tunits - character*(*) - units for time, must be in the form of days
!      since yyyy-mm-dd tt:tt:tt, where yyyy is a year or 0000, mm is a
!      month, dd is a day, and tt:tt:tt is (optional) time or 00:00:00
!     calendar - character*(*) - type of calendar.  Choose from 'noleap',
!      'gregorian','n ka BP', etc.  Use iescal if orbital parameters
!      differ from modern.
!OUTPUT
!     idies - integer - id number of new file for later use
!     ierror - integer - error code, 0 = no error, < 0 = an error occured

      integer idies, nlon, nlat, n3rd, ierror
      character*(*) filen, title, source, history, name3rd
      character*(*) long3rd, units3rd, pos3rd, axis3rd, tunits, calendar
      real*8 alons(nlon), alats(nlat), vals3rd(n3rd)

#ifdef GFORTRAN
#include <netcdf.inc>
#else /* GFORTRAN */
      include 'netcdf.inc'
#endif

      integer ierr, iddlon, idlon, iddlat, idlat, idd3rd, id3rd
      integer iddtime, idtime, iddlend, iddate, idtw, ll
      integer idims(2)

      ierror = 0

!     Open file
!     ---------
      ierr = NF_CREATE(filen,NF_CLOBBER,idies)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile, filen= '//filen
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if

!     Define global attributes
!     ------------------------
      ll = lenchrib(title)
      ierr = NF_PUT_ATT_TEXT(idies,NF_GLOBAL,'title',ll+1,&
      title(1:ll)//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ll = lenchrib(source)
      ierr = NF_PUT_ATT_TEXT(idies,NF_GLOBAL,'source',ll+1,&
      source(1:ll)//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ll = lenchrib(history)
      ierr = NF_PUT_ATT_TEXT(idies,NF_GLOBAL,'history',ll+1,&
      history(1:ll)//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ll = lenchrib(calendar)
      ierr = NF_PUT_ATT_TEXT(idies,NF_GLOBAL,'calendar',ll+1,&
      calendar(1:ll)//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ierr = NF_PUT_ATT_TEXT(idies,NF_GLOBAL,'conventions',9,&
      'NCAR-CSM'//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if

!     Define dimensions
!     -----------------
      ierr = NF_DEF_DIM(idies,'longitude',nlon,iddlon)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ierr = NF_DEF_DIM(idies,'latitude',nlat,iddlat)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      idd3rd = -999
      if (name3rd .ne. 'none') then
         ierr = NF_DEF_DIM(idies,name3rd,n3rd,idd3rd)
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in inifile'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
      end if
      ierr = NF_DEF_DIM(idies,'time',NF_UNLIMITED,iddtime)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ierr = NF_DEF_DIM(idies,'lengthd',10,iddlend)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if

!     Define dimension variables
!     --------------------------
      ierr = NF_DEF_VAR(idies,'longitude',NF_DOUBLE,1,iddlon,idlon)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ierr = NF_DEF_VAR(idies,'latitude',NF_DOUBLE,1,iddlat,idlat)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      if (idd3rd .ne. -999) then
         ierr = NF_DEF_VAR(idies,name3rd,NF_DOUBLE,1,idd3rd,id3rd)
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in inifile'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
      end if
      ierr = NF_DEF_VAR(idies,'time',NF_DOUBLE,1,iddtime,idtime)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if

!     Define variables time_weights and date
!     --------------------------------------
      ierr = NF_DEF_VAR(idies,'time_weights',NF_DOUBLE,1,iddtime,idtw)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      idims(1)=iddlend
      idims(2)=iddtime
      ierr = NF_DEF_VAR(idies,'date',NF_CHAR,2,idims,iddate)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if


!     Attributes for dimension variables
!     ----------------------------------
      ierr = NF_PUT_ATT_TEXT(idies,idlon,'long_name',10,&
      'longitude'//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ierr = NF_PUT_ATT_TEXT(idies,idlon,'units',13,&
      'degrees_east'//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ierr = NF_PUT_ATT_TEXT(idies,idlat,'long_name',9,&
      'latitude'//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ierr = NF_PUT_ATT_TEXT(idies,idlat,'units',14,&
      'degrees_north'//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      if (idd3rd .ne. -999) then
         ll = lenchrib(long3rd)
         ierr = NF_PUT_ATT_TEXT(idies,id3rd,'long_name',&
         ll+1,long3rd(1:ll)//char(0))
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in inifile'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
         ll = lenchrib(units3rd)
         ierr = NF_PUT_ATT_TEXT(idies,id3rd,'units',&
         ll+1,units3rd(1:ll)//char(0))
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in inifile'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
       ll = lenchrib(axis3rd)
         ierr = NF_PUT_ATT_TEXT(idies,id3rd,'axis',&
         ll+1,axis3rd(1:ll)//char(0))
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in inifile'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
      end if
      ierr = NF_PUT_ATT_TEXT(idies,idtime,'long_name',5,&
      'time'//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ll = lenchrib(tunits)
      ierr = NF_PUT_ATT_TEXT(idies,idtime,'units',ll+1,&
      tunits(1:ll)//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ierr = NF_PUT_ATT_TEXT(idies,idtw,'long_name',29,&
      'number of days per time step'//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ierr = NF_PUT_ATT_TEXT(idies,idtw,'units',5,&
      'days'//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ierr = NF_PUT_ATT_TEXT(idies,iddate,'long_name',25,&
      'label for each time step'//char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ll = lenchrib(tunits)
      ierr = NF_PUT_ATT_TEXT(idies,iddate,'units',1,&
      char(0))
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if

!     End define mode, enter data mode
!     --------------------------------
      ierr = NF_ENDDEF(idies)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if

!     Put dimension variables except for time
!     ---------------------------------------
      ierr = NF_PUT_VAR_DOUBLE(idies,idlon,alons)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ierr = NF_PUT_VAR_DOUBLE(idies,idlat,alats)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in inifile'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      if (idd3rd .ne. -999) then
         ierr = NF_PUT_VAR_DOUBLE(idies,id3rd,vals3rd)
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in inifile'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
      end if

!     Don't close file
!     ----------------
      return
end subroutine inifile
