#include "inland_config.h"

#ifdef SINGLE_POINT_MODEL
#error "This subroutine should NOT be compiled for 0D IBIS model option."
#endif

! .....................................................................
! readvar - read a 2-, 3-, or 4-dimensional hyperslab of data
!.....................................................................
subroutine readvar(filen,varname,name3d,istart,icount,values,alons,alats, &
                   vals3d,times,ierror)
      implicit none

! INPUT
! filen - character*(*) - file name from which to read data
! varname - character*(*) - name of variable from which to read
! name3d - character*(*) - name of 3rd, nontime dimension variable.
! Ignored if varname variable is only 3-d.
! istart - integer(*) - starting points along each dimension of
! the variable, for example the 1st point a 4-d variable is (1,1,1,1)
! and the 3rd level and 2nd time step of a 4d variable is (1,1,3,2).
! icount - integer(*) - number of points along each dimension to read,
! for example, to read in a single lat/lon grid from a 4-d variable,
! icount would be (nlon,nlat,1,1)
! OUTPUT
! values - real(*) - returned real values of the designated hyperslab
! alons - real(*) - longitude vector for those points read in
! alats - real(*) - latitude vector for those points read in
! vals3d - real(*) - vector of values of the 3rd dimension (unchanged if
! variable is 2- or 3-d, or if 3rd dimension has character values).
! times - real(*) - time vector vector for those points read in (unchanged
! if variable is 2-d).
! ierror - integer - error code = 0 if no error, < 0 if error occurred
      character*(*) filen, varname, name3d
      integer :: istart(*), icount(*), ierror
      real*8 :: values(*), alons(*), alats(*), vals3d(*), times(*)

#ifdef GFORTRAN
#include <netcdf.inc>
#else /* GFORTRAN */
      include 'netcdf.inc'
#endif

      integer :: idies, idvar, ndims, idlon, idlat, id3d, ierr, itype
      integer :: idtime

      ierror = 0

! Open file, but don't fail if already open
! -----------------------------------------
      ierr = NF_OPEN(filen,NF_NOWRITE,idies)
      if (ierr .ne. NF_NOERR) then
         print *, 'Warning in readvar'
         print *, NF_STRERROR(ierr)
      end if

! Get id of variable
! ------------------
      ierr = NF_INQ_VARID(idies,varname,idvar)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in readvar, 1'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if

! Inquire number of dimensions
! ----------------------------
      ierr = NF_INQ_VARNDIMS(idies,idvar,ndims)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in readvar', 2
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if

! Get variable
! ------------
      ierr = NF_GET_VARA_DOUBLE(idies,idvar,istart,icount,values)
!    ierr = NF_GET_VAR_DOUBLE(idies,idvar,values)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in readvar, 3'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if

! Get values of dimension variables
! ---------------------------------
      ierr = NF_INQ_VARID(idies,'longitude',idlon)
      ierr = NF_GET_VARA_DOUBLE(idies,idlon,istart(1),icount(1),alons)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in readvar, 4'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      ierr = NF_INQ_VARID(idies,'latitude',idlat)
      ierr = NF_GET_VARA_DOUBLE(idies,idlat,istart(2),icount(2),alats)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in readvar, 5'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      if (ndims .ge. 3) then
         ierr = NF_INQ_VARID(idies,'time',idtime)
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in readvar, 6'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
         ierr = NF_GET_VARA_DOUBLE(idies,idtime,istart(ndims),icount(ndims), &
                                   times)
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in readvar, 7'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
      end if

     if (ndims .eq. 4) then
        ierr = NF_INQ_VARID(idies,name3d,id3d)
        if (ierr .ne. NF_NOERR) then
           print *, 'Error in readvar, 8'
           print *, NF_STRERROR(ierr)
           ierror = -1
           return
        end if
        ierr = NF_INQ_VARTYPE(idies,id3d,itype)
        if (ierr .ne. NF_NOERR) then
           print *, 'Error in readvar, 9'
           print *, NF_STRERROR(ierr)
           ierror = -1
           return
        end if
        if (itype .ne. NF_CHAR) ierr = NF_GET_VARA_DOUBLE(idies,id3d,istart(3),&
                                                          icount(3),vals3d)
        if (ierr .ne. NF_NOERR) then
           print *, 'Error in readvar, 10'
           print *, NF_STRERROR(ierr)
           ierror = -1
           return
        end if
     end if

! Close file
! ----------
     ierr = NF_CLOSE(idies)
     if (ierr .ne. NF_NOERR) then
        print *, 'Error in readvar'
        print *, NF_STRERROR(ierr)
        ierror = -1
        return
     end if
     return
end subroutine readvar
