#include "inland_config.h"

#ifdef SINGLE_POINT_MODEL
#error "This subroutine should NOT be compiled for 0D IBIS model option."
#endif

! ---------------------------------------------------------------------
subroutine restartib (iyearp, imonthp)
! ---------------------------------------------------------------------
! reads in restart files, initializes some variables
! ---------------------------------------------------------------------
      use inland_ibispar
      use inland_ibisctl
      use inland_comveg
      use inland_comsoi
      use inland_comsno
      use inland_combcs
      use inland_comwork
      use inland_comsum
      use inland_comatm, only: xstore
 
#if (defined CAMIBIS)
      use abortutils, only: endrun
#endif

      implicit none
! ------------------------------Arguments--------------------------------
! Input arguments
      integer :: iyearp, imonthp

! this subroutine reads the restart values of:
!
! fsnocov = fractional snow cover
! tsno    = temperature of snow
! hsno    = snow depth
! tsoi    = soil temperature
! wisoi   = soil ice content
! wsoi    = soil moisture content
! cbiol   = carbon in leaf biomass pool
! cbiow   = carbon in woody biomass pool
! cbior   = carbon in fine root biomass pool
! sapfrac = sapwood fraction
! clitlm  = leaf metabolic litter
! clitls  = leaf structural litter
! clitll  = leaf lignin litter
! clitrm  = root metabolic litter
! clitrs  = root structural litter
! clitrl  = root lignin litter
! clitwm  = woody metabolic litter
! clitws  = woody structural litter
! clitwl  = woody lignin litter
! falll   = annual leaf litterfall
! fallr   = annual fine root turnover
! fallw   = annual woody turnover
! vegtype0= vegetation type
! fu      = fraction of overall area covered by upper canopy
! fl      = fraction of snow-free area covered by lower  canopy
! totcmic = total microbial carbon
! csoislop= slow soil carbon, protected humus
! csoislon= slow soil carbon, nonprotected humus
! csoipas = passive soil carbon
! decomps = soil decomposition factor
! decompl = litter decomposition factor
! gdd0    = growing degree days 0
! gdd5    = growing degree days 5
! tc      = coldest monthly temperature
! tw      = warmest monthly temperature
! gdd0this= growing degree days 0 of the current year
! gdd5this= growing degree days 5 of the current year
! tcthis  = coldest monthly temperature of the current year
! twthis  = warmest monthly temperature of the current year
! wipud   = ice content of puddles per soil area
! wpud    = liquid content of puddles per soil area
! wliql   = intercepted liquid h2o on lower canopy leaf and stem area (kg m-2)
! wliqs   = intercepted liquid h2o on upper canopy stem area (kg m-2)
! wliqu   = intercepted liquid h2o on upper canopy leaf area (kg m-2)
! wsnol   = intercepted frozen h2o (snow) on lower canopy leaf & stem area (kg m-2)
! wsnos   = intercepted frozen h2o (snow) on upper canopy stem area (kg m-2)
! wsnou   = intercepted frozen h2o (snow) on upper canopy leaf area (kg m-2)
! tu      = temperature of upper canopy leaves (K)
! ts      = temperature of upper canopy stems (K)
! tl      = temperature of lower canopy leaves & stems(K)
! t12     = air temperature at z12 (K)
! t34     = air temperature at z34 (K)
! tlsub   = temperature of lower canopy vegetation buried by snow (K)
! tg      = soil skin temperature (K)
! ti      = snow skin temperature (K)
! q12     = specific humidity of air at z12
! q34     = specific humidity of air at z34
!
! Physiology
! ciub    = intercellular co2 concentration - broadleaf (mol_co2/mol_air)
! ciuc    = intercellular co2 concentration - conifer   (mol_co2/mol_air)
! cils    = intercellular co2 concentration - shrubs    (mol_co2/mol_air)
! cil3    = intercellular co2 concentration - c3 plants (mol_co2/mol_air)
! cil4    = intercellular co2 concentration - c4 plants (mol_co2/mol_air)
! csub    = leaf boundary layer co2 concentration - broadleaf (mol_co2/mol_air)
! csuc    = leaf boundary layer co2 concentration - conifer   (mol_co2/mol_air)
! csls    = leaf boundary layer co2 concentration - shrubs    (mol_co2/mol_air)
! csl3    = leaf boundary layer co2 concentration - c3 plants (mol_co2/mol_air)
! csl4    = leaf boundary layer co2 concentration - c4 plants (mol_co2/mol_air)
! gsub    = upper canopy stomatal conductance - broadleaf  (mol_co2 m-2 s-1)
! gsuc    = upper canopy stomatal conductance - conifer    (mol_co2 m-2 s-1)
! gsls    = lower canopy stomatal conductance - shrubs     (mol_co2 m-2 s-1)
! gsl3    = lower canopy stomatal conductance - c3 grasses (mol_co2 m-2 s-1)
! gsl4    = lower canopy stomatal conductance - c4 grasses (mol_co2 m-2 s-1)
!
! Phenology :
! agddu   = annual accumulated growing degree days for bud burst, upper canopy
! agddl   = annual accumulated growing degree days for bud burst, lower canopy
! tempu   = cold-phenology trigger for trees
! templ   = cold-phenology trigger for grasses/shrubs
! td      = avg daily temp
! a10td    = 10-day avg daily temp
! a10ancub = 10-day average canopy photosynthesis rate - broadleaf
! a10ancuc = 10-day average canopy photosynthesis rate - conifer
! a10ancls = 10-day average canopy photosynthesis rate - shrubs
! a10ancl4 = 10-day average canopy photosynthesis rate - c4 grasses
! a10ancl3 = 10-day average canopy photosynthesis rate - c3 grasses
! a10scalparamu = 10-day average canopy scaling parameter - upper canopy
! a10scalparaml = 10-day average canopy scaling parameter - lower canopy
! a10daylightu = 10-day average daylight - upper canopy
! a10daylightl = 10-day average daylight - lower canopy
! dropu   = drought-phenology trigger for trees
! dropls  = drought-phenology trigger for shrubs
! dropl4  = drought-phenology trigger for c4 grasses
! dropl3  = drought-phenology trigger for c3 grasses
! lail = lai(i,1) : lower canopy lai
! laiu = lai(i,2) : upper canopy lai
! (NOTE: a10ancuc is not used at this point, so its restart entry
! is commented out)
!
! Summation variables used in dynaveg, gdiag and vdiag
!
! aynpp = annual total npp per pft (kg-c/m**2/yr)
! aygpp = annual total gpp per pft (kg-c/m**2/yr)
! ayalit = yearly av. aboveground litter (kg-c/m**2)
! ayblit = yearly av. belowground litter (kg-c/m**2)
! aycsoi = yearly av. soil carbon content (kg-c/m**2)
! ayco2root = yearly av. root respiration (kg-C/m**2/yr)
! ayco2mic = yearly av. microbial respiration (kg-C/m**2/yr)
! yrleach = yearly av. C leaching rate (kg_C m-2/yr)
! ayanlit = yearly av. aboveground litter nitrogen (kg-N/m**2)
! aybnlit = yearly av. belowground litter nitrogen (kg-N/m**2)
! aynsoi = yearly av. total soil nitrogen (kg-N/m**2)
! ynleach = yearly av. N leaching rate (kg_N m-2/yr)
! ayprcp = yearly av. precipitation (mm/year)
! ayaet  = yearly av. aet (mm/yr)
! aytrans = yearly av. transpiration (mm/yr)
! aysrunoff = yearly av. surface runoff (mm/yr)
! aydrainage = yearly av. drainage (mm/yr)
! dwtot = yearly av. change in total water content (mm/yr)
! wtot = yearly h20 content (mm/yr)
! aysolar = annual average incident solar radiation (w/m**2)
! ayreflect = annual average reflected radiation  (W/m**2)
! ayirup = annual average upward ir radiation (w/m**2)
! ayirdown = annual average downward ir radiation (w/m**2)
! aysens = annual average sensible heat flux (w/m**2)
! aylatent = annual average latent heat flux (w/m**2)
!
! aywsoi = yearly av. soil moisture content
! aywisoi = yearly av. soil ice content
! aytsoi = yearly av.  temperature
! ayvwc = annual average 1m volumetric water content (fraction)
! ayawc = annual average 1m plant-available water content (fraction)
! firefac = annual average fire factor
! ayrootbio = annual average live root biomass (kg-C/m**2/yr)
! aynmintot = annual total nitrogen mineralization (kg-N/m**2/yr)
! aycmic = annual av. microbial biomass (kg-c/m**2)
!
! local variables
      integer :: istart(4), icount(4), istat      ! for reading restart vars
      integer :: i, nlevel
      integer :: lenchrib, lf

      character*20 fdir  ! used to construct odd/even file names
      character*1024 filen ! file name
      character*4  chyear
      character*2  chmonth

      data istart / 1,1,1,1 /, icount / nlon,nlat,1,1 /
! ---------------------------------------------------------------------
      icount(1) = nlonsub
      icount(2) = nlatsub

      chyear = '0000'
      if (iyearp .gt. 1000) then
         write(chyear(1:4),'(i4)') iyearp
      else if (iyearp .lt. 10) then
         write(chyear(4:4),'(i1)') iyearp
      else if (iyearp .lt. 100) then
         write(chyear(3:4),'(i2)') iyearp
      else
         write(chyear(2:4),'(i3)') iyearp
      endif

      chmonth = '00'
      if (imonthp .gt. 9) then
         write(chmonth(1:2),'(i2)') imonthp
      else
         write(chmonth(2:2),'(i1)') imonthp
      endif

      fdir = 'restart/'
      lf = lenchrib(fdir)

! dummy variable example, 3-d - copy and change for ne variable
!
!    icount(3) = 1
!    filen = fdir(1:lf)//'dummyv.nc'
!    call readvar(filen,'dummyv','none',istart,icount,
!    > cdummy,work(1),work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
!    if (istat .ne. 0) then
!        write(*,*) 'ERROR in restart, dummyvv'
!        call endrun
!    endif
!    call arr2vec (cdummy, dummyv)
!
! dummy variable example, 4-d, 3rd dim (snowlayer) = nsnolay
!
!      icount(3) = nsnolay
!      filen = fdir(1:lf)//'dummyv.nc'
!      call readvar(filen,'dummyv','snowlayer',istart,icount,
!     > cdummy,work(1),work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
!      if (istat .ne. 0) then
!         write(*,*) 'ERROR in restart, dummyv'
!         call endrun
!      endif
!      do 5 nlevel = 1,nsnolay
!         call arr2vec (cdummy((nlevel-1)*nlonsub*nlatsub + 1),
!     >    dummyv(1,nlevel))
! 5    continue
!
!

! nsnolay variables: xstore
      icount(3) = 3
      if (myid .eq. 0) then
         filen = trim(outdir)//'/inland-restart-xstore-'//chyear//'_'//chmonth//'.nc'
         call readvar(filen,'xstore','snowlayer',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, xstore'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      do 3 nlevel = 1,3
         call arr2vec(cdummy((nlevel-1)*nlonsub*nlatsub + 1), xstore(lbeg,nlevel))
3     continue

! nsnolay variables: tsno and hsno
      icount(3) = nsnolay
      if (myid .eq. 0) then
         filen = trim(outdir)//'/inland-restart-snow-'//chyear//'_'//chmonth//'.nc'
         call readvar(filen,'tsno','snowlayer',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, tsno'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      do 5 nlevel = 1,nsnolay
         call arr2vec(cdummy((nlevel-1)*nlonsub*nlatsub + 1), tsno(lbeg,nlevel))
5     continue

      if (myid .eq. 0) then
         call readvar(filen,'hsno','snowlayer',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, hsno'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      do 10 nlevel = 1,nsnolay
         call arr2vec(cdummy((nlevel-1)*nlonsub*nlatsub + 1), hsno(lbeg,nlevel))
10    continue

! nsoilay variables: tsoi, wisoi, wsoi
      icount(3) = nsoilay

      if (myid .eq. 0) then
         filen = trim(outdir)//'/inland-restart-soil-'//chyear//'_'//chmonth//'.nc'
         call readvar(filen,'tsoi','soillayer',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, tsoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      do 15 nlevel = 1,nsoilay
         call arr2vec(cdummy((nlevel-1)*nlonsub*nlatsub + 1), tsoi(lbeg,nlevel))
15    continue

      if (myid .eq. 0) then
         call readvar(filen,'wisoi','soillayer',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, wisoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      do 20 nlevel = 1,nsoilay
         call arr2vec(cdummy((nlevel-1)*nlonsub*nlatsub + 1), wisoi(lbeg,nlevel))
20    continue

      if (myid .eq. 0) then
         call readvar(filen,'wsoi','soillayer',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, wsoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      do 25 nlevel = 1,nsoilay
         call arr2vec(cdummy((nlevel-1)*nlonsub*nlatsub + 1), wsoi(lbeg,nlevel))
25    continue

! npft variables
      icount(3) = npft

      if (myid .eq. 0) then
         filen = trim(outdir)//'/inland-restart-cbio-'//chyear//'_'//chmonth//'.nc'
         call readvar(filen,'cbiol','pft',istart,icount,cdummy,work(1),work(nlonsub+1), &
                      work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, cbiol'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      do 30 nlevel = 1,npft
         call arr2vec(cdummy((nlevel-1)*nlonsub*nlatsub + 1), cbiol(lbeg,nlevel))
30    continue

      if (myid .eq. 0) then
         call readvar(filen,'cbiow','pft',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, cbiow'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      do 35 nlevel = 1,npft
         call arr2vec(cdummy((nlevel-1)*nlonsub*nlatsub + 1), cbiow(lbeg,nlevel))
35    continue

      if (myid .eq. 0) then
         call readvar(filen,'cbior','pft',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, cbior'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      do 40 nlevel = 1,npft
         call arr2vec(cdummy((nlevel-1)*nlonsub*nlatsub + 1), cbior(lbeg,nlevel))
40    continue

      if (myid .eq. 0) then
         call readvar(filen,'aynpp','pft',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aynpp'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      do 50 nlevel = 1,npft
          call arr2vec(cdummy((nlevel-1)*nlonsub*nlatsub + 1), aynpp(lbeg,nlevel))
50    continue

      if (myid .eq. 0) then
         call readvar(filen,'aygpp','pft',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aygpp'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      do 60 nlevel = 1,npft
         call arr2vec(cdummy((nlevel-1)*nlonsub*nlatsub + 1), aygpp(lbeg,nlevel))
60    continue

! single level variables
      icount(3) = 1

      filen = trim(outdir)//'/inland-restart-2dvar-'//chyear//'_'//chmonth//'.nc'

! intrayear timestep index
      if (myid .eq. 0) then
         call readvar(filen,'anytime','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, anytime'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, anytime)

      do 70 i=1,numlv
         nytime(i) = int( anytime(lbeg) + 0.1 )
70    continue
!
! fsnocov
      if (myid .eq. 0) then
         call readvar(filen,'fsnocov','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, fsnocov'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec (cdummy, fi)

      if (myid .eq. 0) then
         call readvar(filen,'sapfrac','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, sapfrac'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, sapfrac)

      if (myid .eq. 0) then
         call readvar(filen,'clitlm','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, clitlm'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, clitlm)

      if (myid .eq. 0) then
         call readvar(filen,'clitls','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, clitls'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, clitls)

      if (myid .eq. 0) then
         call readvar(filen,'clitll','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, clitll'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, clitll)

      if (myid .eq. 0) then
         call readvar(filen,'clitrm','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, clitrm'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, clitrm)

      if (myid .eq. 0) then
         call readvar(filen,'clitrs','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, clitrs'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, clitrs)

      if (myid .eq. 0) then
         call readvar(filen,'clitrl','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, clitrl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, clitrl)

      if (myid .eq. 0) then
         call readvar(filen,'clitwm','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, clitwm'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, clitwm)

      if (myid .eq. 0) then
         call readvar(filen,'clitws','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, clitws'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, clitws)

      if (myid .eq. 0) then
         call readvar(filen,'clitwl','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, clitwl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, clitwl)

      if (myid .eq. 0) then
         call readvar(filen,'falll','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, falll'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, falll)

      if (myid .eq. 0) then
         call readvar(filen,'fallr','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, fallr'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, fallr)
      
      if (myid .eq. 0) then
         call readvar(filen,'fallw','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, fallw'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, fallw)
      
      if (myid .eq. 0) then
         call readvar(filen,'vegtype0','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, vegtype0'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, vegtype0)
      
      if (myid .eq. 0) then
         call readvar(filen,'fu','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, fu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, fu)
      
      if (myid .eq. 0) then
         call readvar(filen,'fl','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, fl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
       endif
       call arr2vec(cdummy, fl)
       
       if (myid .eq. 0) then
         call readvar(filen,'totcmic','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, totcmic'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, totcmic)
      
      if (myid .eq. 0) then
         call readvar(filen,'csoislop','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, csoislop'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, csoislop)
      
      if (myid .eq. 0) then
         call readvar(filen,'csoislon','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, csoislon'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, csoislon)
      
      if (myid .eq. 0) then
         call readvar(filen,'csoipas','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, csoipas'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, csoipas)
      
      if (myid .eq. 0) then
         call readvar(filen,'decomps','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, decomps'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, decomps)
      
      if (myid .eq. 0) then
         call readvar(filen,'decompl','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, decompl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, decompl)
     
!   read only in the case of dynamic vegetation restart or fixed vegetation 
! using the ccm3 climate
!   In the other cases,  climanl in ibisini calculates gdd0, gdd5, tc, tw, 
! tcmin from climatology

!   The offline model always calls climanl once regardless of dynaveg or restart
! - fzm
!#ifdef COUPLED
!      if ((isimveg .gt. 0) .or. (ccmexist .gt. 0)) then
!   Modified because of read in restartib subroutine 
       if (isimveg .ge. 1) then
         if (myid .eq. 0) then
         call readvar(filen,'gdd0','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1), istat)
            if (istat .ne. 0) then
                  write(*,*) 'ERROR in restart, gdd0'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
            endif
         endif
         call arr2vec(cdummy, gdd0)  
         
         if (myid .eq. 0) then
         call readvar(filen,'gdd5','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1), istat)
            if (istat .ne. 0) then
               write(*,*) 'ERROR in restart, gdd5'
#ifdef CAMIBIS
               call endrun
#else /* CAMIBIS */
               stop
#endif /* CAMIBIS */
            endif
         endif
         call arr2vec(cdummy, gdd5) 

         if (myid .eq. 0) then
         call readvar(filen,'tc','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1), istat)
            if (istat .ne. 0) then
               write(*,*) 'ERROR in restart, tc'
#ifdef CAMIBIS
               call endrun
#else /* CAMIBIS */
               stop
#endif /* CAMIBIS */
            endif
         endif
         call arr2vec(cdummy, tc)

         if (myid .eq. 0) then
         call readvar(filen,'tw','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1), istat)
            if (istat .ne. 0) then
               write(*,*) 'ERROR in restart, tw'
#ifdef CAMIBIS
               call endrun
#else /* CAMIBIS */
               stop
#endif /* CAMIBIS */
            endif
         endif
         call arr2vec(cdummy, tw)
      endif
!#endif /* COUPLED */

      if (myid .eq. 0) then
         call readvar(filen,'gdd0this','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1), istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, gdd0this'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, gdd0this)
      
      if (myid .eq. 0) then
         call readvar(filen,'gdd5this','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1), istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, gdd5this'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, gdd5this)
      
      if (myid .eq. 0) then
         call readvar(filen,'tcthis','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1), istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, tcthis'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, tcthis)
      
      if (myid .eq. 0) then
         call readvar(filen,'twthis','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1), istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, twthis'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, twthis)
      
      if (myid .eq. 0) then
         call readvar(filen,'wipud','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, wipud'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, wipud)
      
      if (myid .eq. 0) then
         call readvar(filen,'wpud','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, wpud'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, wpud)
      
      if (myid .eq. 0) then
         call readvar(filen,'wliql','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, wliql'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, wliql)
      
      if (myid .eq. 0) then
         call readvar(filen,'wliqs','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, wliqs'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, wliqs)
      
      if (myid .eq. 0) then
         call readvar(filen,'wliqu','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, wliqu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, wliqu)
      
      if (myid .eq. 0) then
         call readvar(filen,'wsnol','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, wsnol'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, wsnol)
      
      if (myid .eq. 0) then
         call readvar(filen,'wsnos','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, wsnos'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, wsnos)
      
      if (myid .eq. 0) then
         call readvar(filen,'wsnou','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, wsnou'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, wsnou)
      
      if (myid .eq. 0) then
         call readvar(filen,'tu','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, tu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, tu)
      
      if (myid .eq. 0) then
         call readvar(filen,'ts','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ts'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ts)
      
      if (myid .eq. 0) then
         call readvar(filen,'tl','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, tl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, tl)
      
      if (myid .eq. 0) then
         call readvar(filen,'t12','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, t12'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, t12)
      
      if (myid .eq. 0) then
         call readvar(filen,'t34','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, t34'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, t34)
      
      if (myid .eq. 0) then
         call readvar(filen,'tg','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, tg'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, tg)
      
      if (myid .eq. 0) then
         call readvar(filen,'ti','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ti'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ti)
      
      if (myid .eq. 0) then
         call readvar(filen,'tlsub','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, tlsub'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, tlsub)
      
      if (myid .eq. 0) then
         call readvar(filen,'q12','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, q12'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, q12)
      
      if (myid .eq. 0) then
         call readvar(filen,'q34','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, q34'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, q34)
      
! Physiology variables
      if (myid .eq. 0) then
         call readvar(filen,'ciub','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ciub'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ciub)
      
      if (myid .eq. 0) then
         call readvar(filen,'ciuc','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ciuc'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ciuc)
      
      if (myid .eq. 0) then
         call readvar(filen,'cils','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, cils'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, cils)
      
      if (myid .eq. 0) then
         call readvar(filen,'cil3','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, cil3'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, cil3)
      
      if (myid .eq. 0) then
         call readvar(filen,'cil4','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, cil4'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, cil4)
      
      if (myid .eq. 0) then
         call readvar(filen,'csub','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, csub'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, csub)
      
      if (myid .eq. 0) then
         call readvar(filen,'csuc','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, csuc'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, csuc)
      
      if (myid .eq. 0) then
         call readvar(filen,'csls','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, csls'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, csls)
      
      if (myid .eq. 0) then
         call readvar(filen,'csl3','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, csl3'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, csl3)
      
      if (myid .eq. 0) then
         call readvar(filen,'csl4','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, csl4'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, csl4)
      
      if (myid .eq. 0) then
         call readvar(filen,'gsub','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, gsub'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, gsub)
      
      if (myid .eq. 0) then
         call readvar(filen,'gsuc','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, gsuc'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, gsuc)
      
      if (myid .eq. 0) then
         call readvar(filen,'gsls','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, gsls'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, gsls)
      
      if (myid .eq. 0) then
         call readvar(filen,'gsl3','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, gsl3'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, gsl3)
      
      if (myid .eq. 0) then
         call readvar(filen,'gsl4','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, gsl4'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, gsl4)
      
! Phenology variables
      if (myid .eq. 0) then
         call readvar(filen,'agddu','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, agddu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, agddu)
      
      if (myid .eq. 0) then
         call readvar(filen,'agddl','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, agddl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, agddl)
      
      if (myid .eq. 0) then
         call readvar(filen,'tempu','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, tempu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, tempu)
      
      if (myid .eq. 0) then
         call readvar(filen,'templ','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, templ'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, templ)
      
      if (myid .eq. 0) then
         call readvar(filen,'td','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, td'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, td)
      
      if (myid .eq. 0) then
         call readvar(filen,'a10td','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, a10td'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, a10td)
      
      if (myid .eq. 0) then
         call readvar(filen,'a10ancub','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, a10ancub'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, a10ancub)
      
!      call readvar(filen,'a10ancuc','none',istart,icount,
!     > cdummy,work(1),work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
!      if (istat .ne. 0) then
!         write(*,*) 'ERROR in restart, a10ancuc'
!         call endrun
!      endif
!      call arr2vec (cdummy, a10ancuc)
!
      if (myid .eq. 0) then
         call readvar(filen,'a10ancls','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, a10ancls'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, a10ancls)
      
      if (myid .eq. 0) then
         call readvar(filen,'a10ancl4','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, a10ancl4'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, a10ancl4)
      
      if (myid .eq. 0) then
         call readvar(filen,'a10ancl3','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, a10ancl3'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, a10ancl3)
      
      if (myid .eq. 0) then
         call readvar(filen,'a10scalparamu','none',istart,icount,cdummy, &
                      work(1),work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, a10scalparamu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, a10scalparamu)
      
      if (myid .eq. 0) then
         call readvar(filen,'a10scalparaml','none',istart,icount,cdummy, &
                      work(1),work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, a10scalparaml'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, a10scalparaml)
      
      if (myid .eq. 0) then
         call readvar(filen,'a10daylightu','none',istart,icount,cdummy, &
                      work(1),work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, a10daylightu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, a10daylightu)
      
      if (myid .eq. 0) then
         call readvar(filen,'a10daylightl','none',istart,icount,cdummy, &
                      work(1),work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, a10daylightl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, a10daylightl)
      
      if (myid .eq. 0) then
         call readvar(filen,'dropu','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, dropu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, dropu)
      
      if (myid .eq. 0) then
         call readvar(filen,'dropls','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, dropls'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, dropls)
      
      if (myid .eq. 0) then
         call readvar(filen,'dropl4','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, dropl4'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, dropl4)
      
      if (myid .eq. 0) then
         call readvar(filen,'dropl3','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, dropl3'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, dropl3)
      
      if (myid .eq. 0) then
         call readvar(filen,'laiu','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, laiu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, lai(lbeg,2))
      
      if (myid .eq. 0) then
         call readvar(filen,'lail','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, lail'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, lai(lbeg,1))
      
      if (myid .eq. 0) then
         call readvar(filen,'ayalit','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ayalit'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ayalit(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'ayblit','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ayblit'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ayblit(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'aycsoi','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aycsoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aycsoi(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'ayco2root','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ayco2root'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ayco2root(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'ayco2mic','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ayco2mic'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ayco2mic(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'yrleach','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, yrleach'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, yrleach(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'ayneetot','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) '**WARNING** ayneetot not in restart, using zero'
            ayneetot = 0.0
         endif
      endif
      call arr2vec(cdummy, ayneetot(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'ayanlit','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ayanlit'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ayanlit(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'aybnlit','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aybnlit'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aybnlit(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'aynsoi','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aynsoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aynsoi(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'ynleach','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
! Activate the 2 lines below (and comment the 2 below that) to read older
! ibis restart dump (AAM 03/02/04)
!          write(*,*) '**WARNING** ynleach not in restart, using zero'
!          ynleach = 0.
            write(*,*) 'ERROR in restart, ynleach'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ynleach(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'ayprcp','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ayprcp'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ayprcp(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'ayaet','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ayaet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ayaet(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'aytrans','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aytrans'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aytrans(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'aysrunoff','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aysrunoff'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aysrunoff(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'aydrainage','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aydrainage'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aydrainage(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'dwtot','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, dwtot'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, dwtot(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'wtot','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, wtot'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, wtot(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'aysolar','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aysolar'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aysolar(lbeg))
      
      if (myid .eq. 0) then
! Activate the line below (and delete the line below it) to read older ibis restart
! dump (AAM 03/02/04)
! call readvar(filen,'ayalbedo','none',istart,icount,
         call readvar(filen,'ayreflect','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ayreflect'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ayreflect(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'ayirup','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ayirup'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ayirup(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'ayirdown','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ayirdown'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ayirdown(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'aysens','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aysens'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aysens(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'aylatent','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aylatent'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aylatent(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'aywsoi','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aywsoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aywsoi(lbeg))
      
      if (myid .eq. 0) then
         call readvar(filen,'aywisoi','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aywisoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aywisoi(lbeg))

      if (myid .eq. 0) then
         call readvar(filen,'aytsoi','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aytsoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aytsoi(lbeg))

      if (myid .eq. 0) then
         call readvar(filen,'ayvwc','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ayvwc'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ayvwc(lbeg))

      if (myid .eq. 0) then
         call readvar(filen,'ayawc','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ayawc'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ayawc(lbeg))

      if (myid .eq. 0) then
         call readvar(filen,'firefac','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, firefac'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, firefac(lbeg))

      if (myid .eq. 0) then
         call readvar(filen,'ayrootbio','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, ayrootbio'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, ayrootbio(lbeg))

      if (myid .eq. 0) then
         call readvar(filen,'aynmintot','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aynmintot'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aynmintot(lbeg))

      if (myid .eq. 0) then
         call readvar(filen,'aycmic','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aycmic'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, aycmic(lbeg))

      if (myid .eq. 0) then
         call readvar(filen,'janxinwet','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, janxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, xinwet(lbeg,1))

      if (myid .eq. 0) then
         call readvar(filen,'febxinwet','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, febxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, xinwet(lbeg,2))

      if (myid .eq. 0) then
         call readvar(filen,'marxinwet','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, marxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, xinwet(lbeg,3))

      if (myid .eq. 0) then
         call readvar(filen,'aprxinwet','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, aprxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, xinwet(lbeg,4))

      if (myid .eq. 0) then
         call readvar(filen,'mayxinwet','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, mayxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, xinwet(lbeg,5))

      if (myid .eq. 0) then
         call readvar(filen,'junxinwet','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, junxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, xinwet(lbeg,6))

      if (myid .eq. 0) then
         call readvar(filen,'julxinwet','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, julxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, xinwet(lbeg,7))

      if (myid .eq. 0) then
         call readvar(filen,'augxinwet','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, augxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, xinwet(lbeg,8))

      if (myid .eq. 0) then
         call readvar(filen,'sepxinwet','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, sepxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, xinwet(lbeg,9))

     if (myid .eq. 0) then
         call readvar(filen,'octxinwet','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, octxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, xinwet(lbeg,10))

      if (myid .eq. 0) then
         call readvar(filen,'novxinwet','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, novxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, xinwet(lbeg,11))

      if (myid .eq. 0) then
         call readvar(filen,'decxinwet','none',istart,icount,cdummy,work(1), &
                      work(nlonsub+1),work(2*nlonsub+1),work(3*nlonsub+1),istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in restart, decxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call arr2vec(cdummy, xinwet(lbeg,12))


! only in the case of
!  - dynamic vegetation restart
!  -  fixed vegetation using the ccm3 climate
! In the other cases, existence arrays are based on climatology
! (ibisini calls climanl that calls existence)
      if ((isimveg .gt. 0) .or. (ccmexist .gt. 0)) then
         do 100 i = lbeg, lend
             tcmin(i) = tc(i) + deltat(i)
100      continue
         call existence
      endif
      return
end subroutine restartib
