#include "inland_config.h"
#include "inland_compar.h"

#ifdef SINGLE_POINT_MODEL
#error "This subroutine should NOT be compiled for 0D IBIS model option."
#endif

! ---------------------------------------------------------------------
subroutine wrestart (nday, imonthp)
! ---------------------------------------------------------------------
! instantaneous output for restarts
!---------------------------------------------------------------
      use inland_ibispar
      use inland_ibisctl, only: iyear, iyear0
      use inland_comveg
      use inland_comsoi
      use inland_comsno
      use inland_comwork
      use inland_comsum
      use inland_comatm, only: xstore
      use inland_combcs, only: xinwet
#if (defined CAMIBIS)
      use abortutils, only: endrun
#endif

      implicit none
!-----------------------------------------------------------------------
! this subroutine writes the restart values of:
!
!  fsnocov = fractional snow cover
!  tsno    = temperature of snow
!  hsno    = snow depth
!  tsoi    = soil temperature
!  wisoi   = soil ice content
!  wsoi    = soil moisture content
!  cbiol   = carbon in leaf biomass pool
!  cbiow   = carbon in woody biomass pool
!  cbior   = carbon in fine root biomass pool
!  sapfrac = sapwood fraction
!  clitlm  = leaf metabolic litter
!  clitls  = leaf structural litter
!  clitll  = leaf lignin litter
!  clitrm  = root metabolic litter
!  clitrs  = root structural litter
!  clitrl  = root lignin litter
!  clitwm  = woody metabolic litter
!  clitws  = woody structural litter
!  clitwl  = woody lignin litter
!  falll   = annual leaf litterfall
!  fallr   = annual fine root turnover 
!  fallw   = annual wood litterfall
!  fu      = fraction of overall area covered by upper canopy
!  fl      = fraction of snow-free area covered by lower  canopy
!  vegtype0= vegetation type
!  totcmic = total microbial carbon
!  csoislop= slow soil carbon, protected humus
!  csoislon= slow soil carbon, nonprotected humus
!  csoipas = passive soil carbon
!  gdd0    = growing degree days 0
!  gdd5    = growing degree days 5
!  tc      = coldest monthly temperature
!  tw      = warmest monthly temperature
!  gdd0this= growing degree days 0 of the current year
!  gdd5this= growing degree days 5 of the current year
!  tcthis  = coldest monthly temperature of the current year
!  twthis  = warmest monthly temperature of the current year
!  wipud   = ice content of puddles per soil area
!  wpud    = liquid content of puddles per soil area
!  wliql   = intercepted liquid h2o on lower canopy leaf and stem area (kg m-2)
!  wliqs   = intercepted liquid h2o on upper canopy stem area (kg m-2)
!  wliqu   = intercepted liquid h2o on upper canopy leaf area (kg m-2)
!  wsnol   = intercepted frozen h2o (snow) on lower canopy leaf & stem area (kg m-2)
!  wsnos   = intercepted frozen h2o (snow) on upper canopy stem area (kg m-2)
!  wsnou   = intercepted frozen h2o (snow) on upper canopy leaf area
!     (kg m-2)
!  tu      = temperature of upper canopy leaves (K)
!  ts      = temperature of upper canopy stems (K)
!  tl      = temperature of lower canopy leaves & stems(K)
!  t12     = air temperature at z12 (K)
!  t34     = air temperature at z34 (K)
!  q12     = specific humidity of air at z12
!  q34     = specific humidity of air at z34
!
!  Physiology
!  ciub    = intercellular co2 concentration - broadleaf (mol_co2/mol_air)
!  ciuc    = intercellular co2 concentration - conifer   (mol_co2/mol_air)
!  cils    = intercellular co2 concentration - shrubs    (mol_co2/mol_air)
!  cil3    = intercellular co2 concentration - c3 plants (mol_co2/mol_air)
!  cil4    = intercellular co2 concentration - c4 plants (mol_co2/mol_air)
!  csub    = leaf boundary layer co2 concentration - broadleaf (mol_co2/mol_air)
!  csuc    = leaf boundary layer co2 concentration - conifer   (mol_co2/mol_air)
!  csls    = leaf boundary layer co2 concentration - shrubs    (mol_co2/mol_air)
!  csl3    = leaf boundary layer co2 concentration - c3 plants (mol_co2/mol_air)
!  csl4    = leaf boundary layer co2 concentration - c4 plants (mol_co2/mol_air)
!  gsub    = upper canopy stomatal conductance - broadleaf  (mol_co2 m-2 s-1)
!  gsuc    = upper canopy stomatal conductance - conifer    (mol_co2 m-2 s-1)
!  gsls    = lower canopy stomatal conductance - shrubs     (mol_co2 m-2 s-1)
!  gsl3    = lower canopy stomatal conductance - c3 grasses (mol_co2 m-2 s-1)
!  gsl4    = lower canopy stomatal conductance - c4 grasses (mol_co2 m-2 s-1)
!
!  phenology :
!  agddu   = annual accumulated growing degree days for bud burst, upper canopy
!  agddl   = annual accumulated growing degree days for bud burst, lower canopy
!  tempu   = cold-phenology trigger for trees
!  templ   = cold-phenology trigger for grasses/shrubs
!  td      = daily average air temperature
!  a10td    = 10-day avg daily temp
!  a10ancub = 10-day average canopy photosynthesis rate - broadleaf
!  a10ancuc = 10-day average canopy photosynthesis rate - conifers
!  a10ancls = 10-day average canopy photosynthesis rate - shrubs
!  a10ancl4 = 10-day average canopy photosynthesis rate - c4 grasses
!  a10ancl3 = 10-day average canopy photosynthesis rate - c3 grasses
!  a10scalparamu = 10-day average canopy scaling parameter - upper canopy
!  a10scalparaml = 10-day average canopy scaling parameter - lower canopy
!  a10daylightu = 10-day average daylight - upper canopy
!  a10daylightl = 10-day average daylight - lower canopy
!  dropu   = drought-phenology trigger for trees
!  dropls  = drought-phenology trigger for shrubs
!  dropl4  = drought-phenology trigger for c4 grasses
!  dropl3  = drought-phenology trigger for c3 grasses
!  lail = lai(i,1) : lower canopy lai
!  laiu = lai(i,2) : upper canopy lai
! (NOTE: a10ancuc is not used at this point, so its wrestart entry 
! is commented out)
!
! Summation variables used in dynaveg, gdiag and vdiag
!
!  aynpp = annual total npp per pft (kg-c/m**2/yr)
!  aygpp = annual total gpp per pft (kg-c/m**2/yr)
!  ayalit = yearly av. aboveground litter (kg-c/m**2)
!  ayblit = yearly av. belowground litter (kg-c/m**2)
!  aycsoi = yearly av. soil carbon content (kg-c/m**2)
!  ayco2root = yearly av. root respiration (kg-C/m**2/yr)
!  ayco2mic = yearly av. microbial respiration (kg-C/m**2/yr)
!  yrleach = yearly av. C leaching rate (kg_C m-2/yr)

!  ayanlit = yearly av. aboveground litter nitrogen (kg-N/m**2)
!  aybnlit = yearly av. belowground litter nitrogen (kg-N/m**2)
!  aynsoi = yearly av. total soil nitrogen (kg-N/m**2)
!  ynleach = yearly av. N leaching rate (kg_C m-2/yr)

!  ayprcp = yearly av. precipitation (mm/year)
!  ayaet  = yearly av. aet (mm/yr)
!  aytrans = yearly av. transpiration (mm/yr)
!  aysrunoff = yearly av. surface runoff (mm/yr)
!  aydrainage = yearly av. drainage (mm/yr)
!  dwtot = yearly h20 change (mm/yr)
!  wtot = yearly h20 content (mm/yr)
!
!  aysolar = annual average incident solar radiation (w/m**2)
!  ayreflect = annual average reflected radiation (W/m**2) 
!  ayirup = annual average upward ir radiation (w/m**2)
!  ayirdown = annual average downward ir radiation (w/m**2)
!  aysens = annual average sensible heat flux (w/m**2)
!  aylatent = annual average latent heat flux (w/m**2)
!
!  aywsoi = yearly av. soil moisture content
!  aywisoi = yearly av. soil ice content
!  aytsoi = yearly av.  temperature
!  ayvwc = annual average 1m volumetric water content (fraction)
!  ayawc = annual average 1m plant-available water content (fraction)
!
!  firefac = annual average fire factor
!  ayrootbio = annual average live root biomass (kg-C/m**2/yr)
!  aynmintot = annual total nitrogen mineralization (kg-N/m**2/yr)
!  aycmic = annual av. microbial biomass (kg-c/m**2)

! input variables
      integer nday,    & ! number of days run since iyear0
              imonthp    ! this calendar month

! local variables
      integer nyears,  & ! years of run iyear0
              mstep, lf, lenchrib, n, idies, istat, k, &
              NF_PUT_ATT_TEXT, NF_GLOBAL

      integer istart(4), &
              icount(4)   ! for writing restart vars

      character*21 tunits
      character*20 fdir         ! used to construct odd/even file names
      character*8 tmpdate      ! temp. variable to hold date
      character*8 cdate        ! date to use in history attribute in files
      character*10 tdate        ! character date for time step
      character*80 dimnames(4)  ! names of dimensions for restart vars
      character*80 pftdef(npft) ! plant functional type defs (not used now)
      character*1024 filen      ! file name
      character*4  chyear
      character*2  chmonth

      real*8 slayers(nsnolay),  & ! index for snow layers
             depthsoi(nsoilay), & ! soil layer depths
             pindex(npft),      & ! index for pfts
             ftime,             & ! floating point time value
             tweight              ! time weight (# days/sample)

      data istart / 1,1,1,1 /, &
           icount / nlon,nlat,1,1 /
! ---------------------------------------------------------------------
      icount(1) = nlonsub
      icount(2) = nlatsub
      tweight = 1.
      mstep = 1
      chyear = '0000'
      if (iyear .gt. 1000) then
         write(chyear(1:4),'(i4)') iyear
      else if (iyear .lt. 10) then
         write(chyear(4:4),'(i1)') iyear
      else if (iyear .lt. 100) then
         write(chyear(3:4),'(i2)') iyear
      else
         write(chyear(2:4),'(i3)') iyear
      endif

      chmonth = '00'
      if (imonthp .gt. 9) then
         write(chmonth(1:2),'(i2)') imonthp
      else
         write(chmonth(2:2),'(i1)') imonthp
      endif

      fdir = 'restart/'
      lf = lenchrib(fdir)

! tdate is december of this year, max year = 999
      tdate='DEC000'//char(0)//char(0)//char(0)//char(0)
      nyears = iyear - iyear0 + 1
      if (nyears .lt. 10) then
         write(tdate(6:6),'(i1)') nyears
      else if (nyears .lt. 100) then
         write(tdate(5:6),'(i2)') nyears
      else
         write(tdate(4:6),'(i3)') nyears
      endif

! initialize snow layer indicies, pft names, etc (done as in wyearly)
      if (mstep .eq. 1) then
         call date_and_time(tmpdate)
         cdate(1:2) = tmpdate(5:6)
         cdate(3:3) = '/'
         cdate(4:5) = tmpdate(7:8)
         cdate(6:6) = '/'
         cdate(7:8) = tmpdate(3:4)
         ftime = nday

! time units is days since Dec 31 of the year before iyear0
         tunits = 'days since 0000-12-31'
         write(tunits(12:15),'(i4)') iyear0-1

         do 5 n = 1, nsnolay
            slayers(n) = float(n)
5        continue

         depthsoi(1) = hsoi(1)
         do 10 n = 2, nsoilay
            depthsoi(n) = depthsoi(n-1)+hsoi(n)
10       continue

! define pft by index
         do 12 n = 1, npft
            pindex(n) = n
12       continue

! and by character label
         pftdef(1) = 'trbrevtr - tropical broadleaf evergreen trees'//char(0)
         pftdef(2) = 'trbrdetr - tropical broadleaf drought-deciduous trees' &
                     //char(0)
         pftdef(3) = 'wtbrevtr - warm-temperate broadleaf evergreen trees' &
                     //char(0)
         pftdef(4) = 'tecoevtr - temperate conifer evergreen trees'//char(0)
         pftdef(5) = 'tebrdetr - temperate broadleaf cold-deciduous trees' &
                     //char(0) 
         pftdef(6) = 'bocoevtr - boreal conifer evergreen trees'//char(0)
         pftdef(7) = 'bocodetr - boreal conifer cold-deciduous trees'//char(0)
         pftdef(8) = 'bobrdetr - boreal broadleaf cold-deciduous trees'//char(0)
         pftdef(9) = 'evsh - evergreen shrubs'//char(0)
         pftdef(10) = 'desh - deciduous shrubs'//char(0)
         pftdef(11) = 'c4gr - warm (c4) grasses'//char(0)
         pftdef(12) = 'c3gr - cool (c3) grasses'//char(0)

         dimnames(1) = 'longitude'
         dimnames(2) = 'latitude'

! dimnames(3) is set for each variable seperately
         dimnames(4) = 'time'
      endif

! dummy variable example, 3-d - copy & modify for new variable.
! If new variable is 4-d, see tsno to see how 4-d differs from 3-d.
!      filen = fdir(1:lf)//'dummyv.nc'
!      if (nyears .le. 2) then
!         call inifile(idies,filen,
!     >    'restart file for dummyv',
!     >    'ibis wrestart',cdate,nlonsub,lonscale,nlatsub,latscale,'none','none',
!     >    'none',1,0.,'none',tunits,'gregorian',istat)
!         dimnames(3) = 'time'
!         call inivar(idies,'dummyv',
!     >    'instantaneous dummyv','dummyvs-units',3,dimnames,
!     >    ocean,istat)
!         call endini(idies,istat)
!      endif
!      call vec2arr(dummyv, cdummy)
!      icount(3) = 1
!      call writevar(filen,'dummyv',istart,icount,cdummy,ftime,
!     > tweight,tdate,istat)
!      if (istat .ne. 0) then
!         write(*,*) 'ERROR in wrestart, dummyv'
!         call endrun
!      endif
!
! by Bala on 1/16/2001. Create only 3 restart files
! 2-D variables
! 3-D variables with soil layer as 3rd dimensions
! 3-D variables with snow layer as 3rd dimension
! 3-D variables with pft as 3rd dimension
!
!

! Xstore restart file
! temperature of snow layers
      if (myid .eq. 0) then
         filen = trim(outdir)//'/inland-restart-xstore-'//chyear//'_'//chmonth//'.nc'
         if (mstep .eq. 1) then
            call inifile(idies,filen,'restart file for xstore temperature',   &
                         'ibis wrestart',cdate,nlonsub,lonscale,nlatsub,latscale, &
                         'snowlayer','snow layers top to bottom','none','Z',    &
                         nsnolay,slayers,'down',tunits,'gregorian',istat) 
            dimnames(3) = 'snowlayer'
            call inivar(idies,'xstore','instantaneous xstore temperature', &
                        'degK',4,dimnames,ocean,istat)
            call endini(idies,istat)
         endif
      endif

      do 9 k = 1, 3
         call vec2arr(xstore(lbeg,k), cdummy((k-1)*nlonsub*nlatsub + 1))
9    continue
      if (myid .eq. 0) then
         icount(3) = 3
         call writevar(filen,'xstore',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, xstore'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif




! Snow restart file
! temperature of snow layers
      if (myid .eq. 0) then
         filen = trim(outdir)//'/inland-restart-snow-'//chyear//'_'//chmonth//'.nc'
         if (mstep .eq. 1) then
            call inifile(idies,filen,'restart file for snow temperature',   &
                         'ibis wrestart',cdate,nlonsub,lonscale,nlatsub,latscale, &
                         'snowlayer','snow layers top to bottom','none','Z',    &
                         nsnolay,slayers,'down',tunits,'gregorian',istat) 
            dimnames(3) = 'snowlayer'
            call inivar(idies,'tsno','instantaneous snow cover temperature', &
                        'degK',4,dimnames,ocean,istat)
            call inivar(idies,'hsno','instantaneous snow layer thickness', &
                        'meters',4,dimnames,ocean,istat)
            call endini(idies,istat)
         endif
      endif

      do 15 k = 1, nsnolay
         call vec2arr(tsno(lbeg,k), cdummy((k-1)*nlonsub*nlatsub + 1))
15    continue
      if (myid .eq. 0) then
         icount(3) = nsnolay
         call writevar(filen,'tsno',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, tsno'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! thickness of snow layers
      do 20 k = 1, nsnolay
         call vec2arr(hsno(lbeg,k), cdummy((k-1)*nlonsub*nlatsub + 1))
20    continue
      if (myid .eq. 0) then
         icount(3) = nsnolay
         call writevar(filen,'hsno',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, hsno'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! soil restart file
! temperature
      if (myid .eq. 0) then
         filen = trim(outdir)//'/inland-restart-soil-'//chyear//'_'//chmonth//'.nc'
         if (mstep .eq. 1) then
            call inifile(idies,filen,'restart file for soil temperature',   &
                         'ibis wrestart',cdate,nlonsub,lonscale,nlatsub,latscale, &
                         'soillayer','depth of soil layer bottom','meter','Z',  &
                         nsoilay,depthsoi,'down',tunits,'gregorian',istat)
            dimnames(3) = 'soillayer'
            call inivar(idies,'tsoi','instantaneous soil temperature','degK', &
                        4,dimnames,ocean,istat)
            call inivar(idies,'wisoi','instantaneous fraction of soil pore '// &
                        'space containing ice','fraction',4,dimnames,ocean,  &
                        istat)
            call inivar(idies,'wsoi','instantaneous fraction of soil pore '// &
                        'space containing water','fraction',4,dimnames,ocean, &
                        istat)
            call endini(idies,istat)
         endif
      endif

      do 25 k = 1, nsoilay
         call vec2arr(tsoi(lbeg,k), cdummy((k-1)*nlonsub*nlatsub + 1))
25    continue
      if (myid .eq. 0) then
         icount(3) = nsoilay
         call writevar(filen,'tsoi',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, tsoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! ice content of soil
      do 30 k = 1, nsoilay
         call vec2arr(wisoi(lbeg,k), cdummy((k-1)*nlonsub*nlatsub + 1))
30    continue
      if (myid .eq. 0) then
         icount(3) = nsoilay
         call writevar(filen,'wisoi',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, wisoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! water content of soil
      do 35 k = 1, nsoilay
         call vec2arr(wsoi(lbeg,k), cdummy((k-1)*nlonsub*nlatsub + 1))
35    continue
      if (myid .eq. 0) then
         icount(3) = nsoilay
         call writevar(filen,'wsoi',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, wsoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! Carbon pools and fluxes per pft restart file
      if (myid .eq. 0) then
         filen = trim(outdir)//'/inland-restart-cbio-'//chyear//'_'//chmonth//'.nc'
         if (mstep .eq. 1) then
            call inifile(idies,filen,'restart file for carbon pools and '//    &
                         'fluxes per pft','ibis wrestart',cdate,nlonsub,lonscale, &
                         nlatsub,latscale,'pft','plant functional type','none','E',   &
                         npft,pindex,'none',tunits,'gregorian',istat)

! add global attribute to define pfts with text, use netcdf low-level command
            istat = NF_PUT_ATT_TEXT(idies,NF_GLOBAL,'pft_definition',npft*80, &
                                    pftdef)
            dimnames(3) = 'pft'
            call inivar(idies,'cbiol','instantaneous carbon in leaf biomass '//&
                        'pool','kg/m^2',4,dimnames,ocean,istat)
            call inivar(idies,'cbiow','instantaneous carbon in wood biomass '//&
                        'pool','kg/m^2',4,dimnames,ocean,istat)
            call inivar(idies,'cbior','instantaneous carbon in root biomass '//&
                        'pool','kg/m^2',4,dimnames,ocean,istat)
            call inivar(idies,'aynpp','current value of annual sum of npp', &
                        'kg-C/m^2/yr',4,dimnames,ocean,istat)
            call inivar(idies,'aygpp','current value of annual sum of gpp', &
                        'kg-C/m^2/yr',4,dimnames,ocean,istat)
            call endini(idies,istat)
         endif
      endif

! carbon in leaf
      do 55 k = 1, npft
         call vec2arr(cbiol(lbeg,k), cdummy((k-1)*nlonsub*nlatsub + 1))
55    continue
      if (myid .eq. 0) then
         icount(3) = npft
         call writevar(filen,'cbiol',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, cbiol'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! carbon in wood
      do 60 k = 1, npft
         call vec2arr(cbiow(lbeg,k), cdummy((k-1)*nlonsub*nlatsub + 1))
60    continue
      if (myid .eq. 0) then
         icount(3) = npft
         call writevar(filen,'cbiow',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, cbiow'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! carbon in root
      do 65 k = 1, npft
         call vec2arr(cbior(lbeg,k), cdummy((k-1)*nlonsub*nlatsub + 1))
65    continue
      if (myid .eq. 0) then
         icount(3) = npft
         call writevar(filen,'cbior',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, cbior'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! current average npp per pft
      do 70 k = 1, npft
         call vec2arr(aynpp(lbeg,k), cdummy((k-1)*nlonsub*nlatsub + 1))
70    continue
      if (myid .eq. 0) then
         icount(3) = npft
         call writevar(filen,'aynpp',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aynpp'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! current average gpp per pft
      do 75 k = 1, npft
         call vec2arr(aygpp(lbeg,k), cdummy((k-1)*nlonsub*nlatsub + 1))
75    continue
      if (myid .eq. 0) then
         icount(3) = npft
         call writevar(filen,'aygpp',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aygpp'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! All other 2-d variables for restart
!
! fractional snow cover
      if (myid .eq. 0) then
         filen = trim(outdir)//'/inland-restart-2dvar-'//chyear//'_'//chmonth//'.nc'
         if (mstep .eq. 1) then
            call inifile(idies,filen,'restart file for fractional snow cover', &
                         'ibis wrestart',cdate,nlonsub,lonscale,nlatsub,latscale,    &
                         'none','none','none','Z',1,0.,'none',tunits,'gregorian',  &
                         istat)
            dimnames(3) = 'time'

            call inivar(idies,'anytime','intrayear timestep index','dimless',  &
                        3,dimnames,ocean,istat)
            call inivar(idies,'fsnocov','instantaneous fractional snow cover', &
                        'fraction',3,dimnames,ocean,istat)
            call inivar(idies,'sapfrac','instantaneous sapwood fraction', &
                        'fraction',3,dimnames,ocean,istat)
            call inivar(idies,'clitlm','instantaneous leaf metabolic litter'// &
                        'carbon','kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'clitls','instantaneous leaf structural litter'//&
                        'carbon','kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'clitll','instantaneous leaf lignin litter '// &
                        'carbon','kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'clitrm','instantaneous root metabolic litter '//&
                        'carbon','kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'clitrs','instantaneous root structural litter'//&
                        ' carbon','kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'clitrl','instantaneous root lignin litter '// &
                        'carbon','kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'clitwm','instantaneous woody metabolic litter'//&
                        ' carbon','kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'clitws','instantaneous woody structural '// &
                        'litter carbon','kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'clitwl','instantaneous woody lignin litter '// &
                        'carbon','kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'falll','annual leaf litterfall carbon','kg/m^2',&
                        3,dimnames,ocean,istat)
            call inivar(idies,'fallr','annual fine root turnover carbon', &
                        'kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'fallw','annual wood turnover carbon','kg/m^2', &
                        3,dimnames,ocean,istat)
            call inivar(idies,'vegtype0','vegetation type','none',3,dimnames, &
                        ocean,istat)
            call inivar(idies,'fu','upper canopy fractional cover','none',3, &
                        dimnames,ocean,istat)
            call inivar(idies,'fl', 'upper canopy fractional cover (snow-free area)', &
                        'none',3,dimnames,ocean,istat)
            call inivar(idies,'totcmic','instantaneous total microbial carbon',&
                        'kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'csoislop','instantaneous slow soil carbon protected humus', &
                        'kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'csoislon', 'instantaneous slow soil carbon nonprotected humus', &
                        'kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'csoipas','instantaneous passive soil carbon', &
                        'kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'decomps','soil decomposition factor','none',3, &
                        dimnames,ocean,istat)
            call inivar(idies,'decompl','litter decomposition factor','none', &
                        3,dimnames,ocean,istat)
! TODO: theoretically fixed vegetation runs does not require gdd0/5 gddthis0/5
!      AND pfts information to be written. Then we should disable writing this
!      on static vegetation runs!
            call inivar(idies,'gdd0','instantaneous growing degree days above 0 deg_C', &
                        'days degC',3,dimnames,ocean,istat)
! TODO: theoretically fixed vegetation runs does not require gdd0/5 gddthis0/5
!      AND pfts information to be written. Then we should disable writing this
!      on static vegetation runs!
            call inivar(idies,'gdd5','instantaneous growing degree days above 5 deg_C', &
                        'days degC',3,dimnames,ocean,istat)
            call inivar(idies,'tc','instantaneous coldest monthly temperature',&
                        'degC',3,dimnames,ocean,istat)
            call inivar(idies,'tw','instantaneous warmest monthly temperature',&
                        'degC',3,dimnames,ocean,istat)
! TODO: theoretically fixed vegetation runs does not require gdd0/5 gddthis0/5
!      AND pfts information to be written. Then we should disable writing this
!      on static vegetation runs!
            call inivar(idies,'gdd0this','instantaneous growing degree days above 0 deg_C for current year', &
! TODO: theoretically fixed vegetation runs does not require gdd0/5 gddthis0/5
!      AND pfts information to be written. Then we should disable writing this
!      on static vegetation runs!
                        'days degC',3,dimnames,ocean,istat)
            call inivar(idies,'gdd5this','instantaneous growing degree days above 5 deg_C for current year', &
                        'days degC',3,dimnames,ocean,istat)
            call inivar(idies,'tcthis','instantaneous coldest monthly temperature for current year', &
                        'degC',3,dimnames,ocean,istat)
            call inivar(idies,'twthis','instantaneous warmest monthly temperature for current year', &
                        'degC',3,dimnames,ocean,istat)

            call inivar(idies,'wipud','instantaneous ice content of puddles', &
                        'kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'wpud','instantaneous liquid water content of puddles', &
                        'kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'wliql', &
                        'instantaneous intercepted water on lower canopy', &
                        'kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'wliqs', &
                        'instantaneous intercepted water on upper canopy stems', &
                        'kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'wliqu', &
                        'instantaneous intercepted water on upper canopy leaves', &
                        'kg/m^2',3,dimnames,ocean,istat)

            call inivar(idies,'wsnol', &
                        'instantaneous intercepted snow on lower canopy', &
                        'kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'wsnos', &
                        'instantaneous intercepted snow on upper canopy stems', &
                        'kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'wsnou', &
                       'instantaneous intercepted snow on upper canopy leaves',&
                        'kg/m^2',3,dimnames,ocean,istat)
            call inivar(idies,'tu', &
                        'instantaneous temperature of upper canopy leaves', &
                        'K',3,dimnames,ocean,istat)
            call inivar(idies,'ts', &
                        'instantaneous temperature of upper canopy stems', &
                        'K',3,dimnames,ocean,istat)
            call inivar(idies,'tl', &
                        'instantaneous temperature of lower canopy leaves', &
                        'K',3,dimnames,ocean,istat)
            call inivar(idies,'t12', &
                        'instantaneous temperature at level z12', &
                        'K',3,dimnames,ocean,istat)
            call inivar(idies,'t34', &
                        'instantaneous temperature at level z34', &
                        'K',3,dimnames,ocean,istat)
            call inivar(idies,'tlsub', &
                      'instantaneous temperature of snow burried lower canopy',&
                        'K',3,dimnames,ocean,istat)
            call inivar(idies,'tg', &
                        'instantaneous soil skin temperature', &
                        'K',3,dimnames,ocean,istat)
            call inivar(idies,'ti', &
                        'instantaneous snow skin temperature', &
                        'K',3,dimnames,ocean,istat)
            call inivar(idies,'q12', &
                        'instantaneous humidity at level z12', &
                        'K',3,dimnames,ocean,istat)
            call inivar(idies,'q34', &
                        'instantaneous humidity at level z34', &
                        'K',3,dimnames,ocean,istat)
            call inivar(idies,'ciub', &
                        'intercellular co2 concentration - broadleaf', &
                        'mol_co2/mol_air',3,dimnames,ocean,istat)
            call inivar(idies,'ciuc', &
                        'intercellular co2 concentration - conifer', &
                        'mol_co2/mol_air',3,dimnames,ocean,istat)
            call inivar(idies,'cils', &
                        'intercellular co2 concentration - shrub', &
                        'mol_co2/mol_air',3,dimnames,ocean,istat)
            call inivar(idies,'cil3', &
                        'intercellular co2 concentration - c3 grasses', &
                        'mol_co2/mol_air',3,dimnames,ocean,istat)
            call inivar(idies,'cil4', &
                        'intercellular co2 concentration - c4 grasses', &
                        'mol_co2/mol_air',3,dimnames,ocean,istat)
            call inivar(idies,'csub', &
                        'leaf boundary layer co2 concentration - broadleaf', &
                        'mol_co2/mol_air',3,dimnames,ocean,istat)
            call inivar(idies,'csuc', &
                        'leaf boundary layer co2 concentration - conifer', &
                        'mol_co2/mol_air',3,dimnames,ocean,istat)
            call inivar(idies,'csls', &
                        'leaf boundary layer  co2 concentration - shrub', &
                        'mol_co2/mol_air',3,dimnames,ocean,istat)
            call inivar(idies,'csl3', &
                        'leaf boundary layer  co2 concentration - c3 grasses', &
                        'mol_co2/mol_air',3,dimnames,ocean,istat)
            call inivar(idies,'csl4', &
                        'leaf boundary layer co2 concentration - c4 grasse', &
                        'mol_co2/mol_air',3,dimnames,ocean,istat)
            call inivar(idies,'gsub', &
                        'upper canopy stomatal conductance - broadleaf', &
                        'mol_co2 m-2 s-1',3,dimnames,ocean,istat)
            call inivar(idies,'gsuc', &
                        'upper canopy stomatal conductance - conifer', &
                        'mol_co2 m-2 s-1',3,dimnames,ocean,istat)
            call inivar(idies,'gsls', &
                        'upper canopy stomatal conductance - shrub', &
                        'mol_co2 m-2 s-1',3,dimnames,ocean,istat)
            call inivar(idies,'gsl3', &
                        'upper canopy stomatal conductance - c3 grasses', &
                        'mol_co2 m-2 s-1',3,dimnames,ocean,istat)
            call inivar(idies,'gsl4', &
                        'upper canopy stomatal conductance - c4 grasses', &
                        'mol_co2 m-2 s-1',3,dimnames,ocean,istat)
            call inivar(idies,'agddu', &
                        'instantaneous growing degree days', &
                        'days degC',3,dimnames,ocean,istat)
            call inivar(idies,'agddl', 'instantaneous ','days degC',3,dimnames,&
                        ocean,istat)
            call inivar(idies,'tempu','cold phenology trigger for trees', &
                        'dimensionless',3,dimnames,ocean,istat)
            call inivar(idies,'templ', &
                        'cold phenology trigger for grasses/shrubs', &
                        'dimensionless',3,dimnames,ocean,istat)
            call inivar(idies,'td','average daily air T','K',3,dimnames, &
                        ocean,istat)
            call inivar(idies,'a10td','10-day average daily air T','K',3, &
                        dimnames,ocean,istat)
            call inivar(idies,'a10ancub', &
                        '10-day average canopy photosynth. rate, broadleaf', &
                        'mol_co2 m-2 s-1',3,dimnames,ocean,istat)
            call inivar(idies,'a10ancls', &
                        '10-day average canopy photosynth. rate, shrubs', &
                        'mol_co2 m-2 s-1',3,dimnames,ocean,istat)
            call inivar(idies,'a10ancl4', &
                        '10-day average canopy photosynth. rate, c4 grasses', &
                        'mol_co2 m-2 s-1',3,dimnames,ocean,istat)
            call inivar(idies,'a10ancl3', &
                        '10-day average canopy photosynth. rate, c3 grasses', &
                        'mol_co2 m-2 s-1',3,dimnames,ocean,istat)
            call inivar(idies,'a10scalparamu','10-day average canopy scaling parameter, upper canopy', &
                        'none',3,dimnames,ocean,istat)
            call inivar(idies,'a10scalparaml','10-day average canopy scaling parameter, lower canopy', &
                        'none',3,dimnames,ocean,istat)
            call inivar(idies,'a10daylightu','10-day average daylight, upper canopy', &
                        'W m-2',3,dimnames,ocean,istat)
            call inivar(idies,'a10daylightl','10-day average daylight, lower canopy', &
                        'W m-2',3,dimnames,ocean,istat)
            call inivar(idies,'dropu','drought-pheno. trigger for trees', &
                        'dimensionless',3,dimnames,ocean,istat)
            call inivar(idies,'dropls','drought-pheno. trigger for shrubs', &
                        'dimensionless',3,dimnames,ocean,istat)
            call inivar(idies,'dropl4','drought-pheno. trigger for c4 grasses', &
                        'dimensionless',3,dimnames,ocean,istat)
            call inivar(idies,'dropl3','drought-pheno. trigger for c3 grasses', &
                        'dimensionless',3,dimnames,ocean,istat)
            call inivar(idies,'laiu','LAI of upper canopy','dimensionless',3, &
                        dimnames,ocean,istat)
            call inivar(idies,'lail','LAI of lower canopy','dimensionless',3, &
                        dimnames,ocean,istat)

            call inivar(idies,'ayalit','yearly av. aboveground litter', &
                        '(kg-c/m**2)',3,dimnames,ocean,istat)
            call inivar(idies,'ayblit','yearly av. belowground litter', &
                        '(kg-c/m**2)',3,dimnames,ocean,istat)
            call inivar(idies,'aycsoi','yearly av. soil carbon content', &
                        '(kg-c/m**2)',3,dimnames,ocean,istat)
            call inivar(idies,'ayco2root','yearly av. root respiration', &
                        '(kg-C/m**2/yr)',3,dimnames,ocean,istat)
            call inivar(idies,'ayco2mic','yearly av. microbial respiration', &
                        '(kg-C/m**2/yr)',3,dimnames,ocean,istat)
            call inivar(idies,'yrleach','yearly av. C leaching rate', &
                        '(kg-C/m**2/yr)',3,dimnames,ocean,istat)
            call inivar(idies,'ayneetot','yearly TNEE','(kg-C/m**2/yr)',3, &
                        dimnames,ocean,istat)
            call inivar(idies,'ayanlit','yearly av. aboveground litter nitrogen', &
                        '(kg-N/m**2)',3,dimnames,ocean,istat)
            call inivar(idies,'aybnlit','yearly av. belowground litter nitrogen', &
                        '(kg-N/m**2)',3,dimnames,ocean,istat)
            call inivar(idies,'aynsoi','yearly av. soil nitrogen content', &
                        '(kg-N/m**2)',3,dimnames,ocean,istat)
            call inivar(idies,'ynleach','yearly av. N leaching rate', &
                        '(kg-N/m**2/yr)',3,dimnames,ocean,istat)
            call inivar(idies,'ayprcp','yearly av. precipitation','(mm/yr)', &
                        3,dimnames,ocean,istat)
            call inivar(idies,'ayaet','yearly av. actual evapotranspiration', &
                        '(mm/yr)',3,dimnames,ocean,istat)
            call inivar(idies,'aytrans','yearly av. transpiration','(mm/yr)', &
                        3,dimnames,ocean,istat)
            call inivar(idies,'aysrunoff','yearly av. surface runoff', &
                        '(mm/yr)',3,dimnames,ocean,istat)
            call inivar(idies,'aydrainage','yearly av. drainage','(mm/yr)',3, &
                        dimnames,ocean,istat)
            call inivar(idies,'dwtot','yearly av. h20 change','(mm/yr)',3, &
                        dimnames,ocean,istat)
            call inivar(idies,'wtot','yearly av. h20 content','(mm/yr)',3, &
                        dimnames,ocean,istat)

            call inivar(idies,'aysolar','yearly av. incident solar radiation', &
                        '(w/m**2)',3,dimnames,ocean,istat)
            call inivar(idies,'ayreflect','yearly av. albedo','(fraction)',3, &
                        dimnames,ocean,istat)
            call inivar(idies,'ayirup','yearly av. upward ir radiation', &
                        '(w/m**2)',3,dimnames,ocean,istat)
            call inivar(idies,'ayirdown','yearly av. downward ir radiation', &
                        '(w/m**2)',3,dimnames,ocean,istat)
            call inivar(idies,'aysens','yearly av. sensible heat flux', &
                        '(w/m**2)',3,dimnames,ocean,istat)
            call inivar(idies,'aylatent','yearly av. latent heat flux', &
                        '(w/m**2)',3,dimnames,ocean,istat)
            call inivar(idies,'aywsoi','yearly av. 1m volumetric water content', &
                        '(fraction)',3,dimnames,ocean,istat)
            call inivar(idies,'aywisoi','yearly av. 1m volumetric ice content', &
                        '(fraction)',3,dimnames,ocean,istat)
            call inivar(idies,'aytsoi','yearly av. 1m soil temp.', &
                        '(fraction)',3,dimnames,ocean,istat)
            call inivar(idies,'ayvwc','yearly av. annual average 1m volumetric water content', &
                        '(fraction)',3,dimnames,ocean,istat)
            call inivar(idies,'ayawc','yearly av. annual average 1m plant available water content', &
                        '(fraction)',3,dimnames,ocean,istat)

            call inivar(idies,'firefac','yearly av. live root biomass', &
                        '(kg-C/m**2/yr)',3,dimnames,ocean,istat)
            call inivar(idies,'ayrootbio','yearly av. live root biomass', &
                        '(kg-C/m**2/yr)',3,dimnames,ocean,istat)
            call inivar(idies,'aynmintot','yearly av. total nitrogen mineralization', &
                        '(kg-N/m**2/yr)',3,dimnames,ocean,istat)
            call inivar(idies,'aycmic','yearly av. microbial biomass', &
                        '(kg-c/m**2)',3,dimnames,ocean,istat)
            call inivar(idies,'janxinwet','climatologic january precipitation days', &
                        '(days/month)',3,dimnames,ocean,istat)
            call inivar(idies,'febxinwet','climatologic february precipitation days', &
                        '(days/month)',3,dimnames,ocean,istat)
            call inivar(idies,'marxinwet','climatologic march precipitation days', &
                        '(days/month)',3,dimnames,ocean,istat)
            call inivar(idies,'aprxinwet','climatologic april precipitation days', &
                        '(days/month)',3,dimnames,ocean,istat)
            call inivar(idies,'mayxinwet','climatologic may precipitation days', &
                        '(days/month)',3,dimnames,ocean,istat)
            call inivar(idies,'junxinwet','climatologic june precipitation days', &
                        '(days/month)',3,dimnames,ocean,istat)
            call inivar(idies,'julxinwet','climatologic july precipitation days', &
                        '(days/month)',3,dimnames,ocean,istat)
            call inivar(idies,'augxinwet','climatologic august precipitation days', &
                        '(days/month)',3,dimnames,ocean,istat)
            call inivar(idies,'sepxinwet','climatologic september precipitation days', &
                        '(days/month)',3,dimnames,ocean,istat)
            call inivar(idies,'octxinwet','climatologic october precipitation days', &
                        '(days/month)',3,dimnames,ocean,istat)
            call inivar(idies,'novxinwet','climatologic november precipitation days', &
                        '(days/month)',3,dimnames,ocean,istat)
            call inivar(idies,'decxinwet','climatologic december precipitation days', &
                        '(days/month)',3,dimnames,ocean,istat)

            call endini(idies,istat)

        endif
      endif

! intrayear timestep index
      do n=lbeg,lend
         anytime(n) = nytime(1)
      enddo
      call vec2arr(anytime, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'anytime',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, anytime'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! fractional snow cover
      call vec2arr(fi, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'fsnocov',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, fsnocov'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! sapwood fraction
      call vec2arr(sapfrac, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'sapfrac',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, sapfrac'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! leaf metabolic litter
      call vec2arr(clitlm, cdummy)
      if (myid .eq. 0) then
        icount(3) = 1
         call writevar(filen,'clitlm',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, clitlm'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! leaf structural carbon litter
      call vec2arr(clitls, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'clitls',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, clitls'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! leaf lignin carbon litter
      call vec2arr(clitll, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'clitll',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, clitll'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! root metabolic litter
      call vec2arr(clitrm, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'clitrm',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, clitrm'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
        endif
      endif

! root structural litter
      call vec2arr(clitrs, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'clitrs',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, clitrs'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! root lignin litter
      call vec2arr(clitrl, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'clitrl',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, clitrl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! woody metabolic litter
      call vec2arr(clitwm, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'clitwm',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, clitwm'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! woody structural litter
      call vec2arr(clitws, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'clitws',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, clitws'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! woody lignin litter
      call vec2arr(clitwl, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'clitwl',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, clitwl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! annual leaf litterfall
      call vec2arr(falll, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'falll',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, falll'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! annual fine root turnover 
      call vec2arr(fallr, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'fallr',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, fallr'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! annual wood turnover 
      call vec2arr(fallw, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'fallw',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, fallw'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! Vegetation type
      call vec2arr(vegtype0, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'vegtype0',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, vegtype0'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! Upper canopy fractional cover
      call vec2arr(fu, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'fu',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, fu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! Lower canopy fractional cover
      call vec2arr(fl, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'fl',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, fl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! total microbial carbon
      call vec2arr(totcmic, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'totcmic',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, totcmic'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! slow soil carbon, protected humus
      call vec2arr(csoislop, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'csoislop',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, csoislop'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! slow soil carbon, nonprotected humus
      call vec2arr(csoislon, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'csoislon',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, csoislon'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! passive soil carbon
      call vec2arr(csoipas, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'csoipas',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, csoipas'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! average soil decomposition factor
      call vec2arr(decomps, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'decomps',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, decomps'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! average litter decomposition factor
      call vec2arr(decompl, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'decompl',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, decompl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! growing degree days
! TODO: theoretically fixed vegetation runs does not require gdd0/5 gddthis0/5
!      AND pfts information to be written. Then we should disable writing this
!      on static vegetation runs!
      call vec2arr(gdd0, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'gdd0',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, gdd0'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! TODO: theoretically fixed vegetation runs does not require gdd0/5 gddthis0/5
!      AND pfts information to be written. Then we should disable writing this
!      on static vegetation runs!
      call vec2arr(gdd5, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'gdd5',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, gdd5'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! coldest monthly temperature
      call vec2arr(tc, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'tc',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, tc'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! warmest monthly temperature
      call vec2arr(tw, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'tw',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, tw'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! growing degree days
! TODO: theoretically fixed vegetation runs does not require gdd0/5 gddthis0/5
!      AND pfts information to be written. Then we should disable writing this
!      on static vegetation runs!
      call vec2arr(gdd0this, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'gdd0this',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, gdd0this'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! TODO: theoretically fixed vegetation runs does not require gdd0/5 gddthis0/5
!      AND pfts information to be written. Then we should disable writing this
!      on static vegetation runs!
      call vec2arr(gdd5this, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'gdd5this',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, gdd5this'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! coldest monthly temperature
      call vec2arr(tcthis, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'tcthis',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, tcthis'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! warmest monthly temperature
      call vec2arr(twthis, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'twthis',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, twthis'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! ice content of puddles
      call vec2arr(wipud, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'wipud',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, wipud'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! liquid content of puddles
      call vec2arr(wpud, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'wpud',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, wpud'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! intercepted water by lower canopy leaves and stems
      call vec2arr(wliql, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'wliql',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, wliql'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! intercepted water upper canopy stems 
      call vec2arr(wliqs, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'wliqs',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, wliqs'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! intercepted water by upper canopy leaves
      call vec2arr(wliqu, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'wliqu',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, wliqu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! intercepted snow by lower canopy leaves and stems
      call vec2arr(wsnol, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'wsnol',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, wsnol'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! intercepted snow by upper canopy stems
      call vec2arr(wsnos, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'wsnos',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, wsnos'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! intercepted snow by upper canopy leaves
      call vec2arr(wsnou, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'wsnou',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, wsnou'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! temperature of upper canopy leaves
      call vec2arr(tu, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'tu',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, tu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! temperature of upper canopy stems
      call vec2arr(ts, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ts',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ts'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! temperature of lower canopy leaves
      call vec2arr(tl, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'tl',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, tl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! temperature at level z12
      call vec2arr(t12, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'t12',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, t12'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! temperature at level z34
      call vec2arr(t34, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'t34',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, t34'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! temperature of snow burried lower canopy
      call vec2arr(tlsub, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'tlsub',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, tlsub'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! soil skin temperature
      call vec2arr(tg, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'tg',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, tg'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! snow skin temperature
      call vec2arr(ti, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ti',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ti'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! humidity at level z12
      call vec2arr(q12, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'q12',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, q12'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! humidity at level z34
      call vec2arr(q34, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'q34',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, q34'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! Physiology variables

! intercellular co2 concentration
      call vec2arr(ciub, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ciub',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ciub'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call vec2arr(ciuc, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ciuc',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ciuc'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call vec2arr(cils, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'cils',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, cils'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call vec2arr(cil3, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'cil3',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, cil3'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call vec2arr(cil4, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'cil4',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, cil4'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! leaf boundary layer co2 concentration
      call vec2arr(csub, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'csub',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, csub'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call vec2arr(csuc, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'csuc',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, csuc'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call vec2arr(csls, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'csls',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, csls'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call vec2arr(csl3, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'csl3',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, csl3'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call vec2arr(csl4, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'csl4',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, csl4'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! stomatal conductance
      call vec2arr(gsub, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'gsub',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, gsub'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call vec2arr(gsuc, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'gsuc',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, gsuc'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call vec2arr(gsls, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'gsls',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, gsls'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call vec2arr(gsl3, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'gsl3',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, gsl3'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
      call vec2arr(gsl4, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'gsl4',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, gsl4'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! Phenology variables
! annual accumulated growing degree days for bud burst, upper canopy
      call vec2arr(agddu, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'agddu',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, agddu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! annual accumulated growing degree days for bud burst, lower canopy
      call vec2arr(agddl, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'agddl',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, agddl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! cold-phenology trigger for trees
      call vec2arr(tempu, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'tempu',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, tempu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! cold-phenology trigger for grasses/shrubs
      call vec2arr(templ, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'templ',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, templ'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! average daily air temperature
      call vec2arr(td, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'td',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, td'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! 10-day average daily air temperature
      call vec2arr(a10td, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'a10td',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, a10td'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! 10-day average canopy photosynthesis rate - broadleaf
      call vec2arr(a10ancub, cdummy)
      if (myid .eq. 0) then
          icount(3) = 1
          call writevar(filen,'a10ancub',istart,icount,cdummy,ftime,tweight, &
                        tdate,istat)
          if (istat .ne. 0) then
             write(*,*) 'ERROR in wrestart, a10ancub'
#ifdef CAMIBIS
             call endrun
#else /* CAMIBIS */
             stop
#endif /* CAMIBIS */
          endif
      endif

! 10-day average canopy photosynthesis rate - shrubs
      call vec2arr(a10ancls, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'a10ancls',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, a10ancls'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
        endif
      endif

! 10-day average canopy photosynthesis rate - c4 grasses
      call vec2arr(a10ancl4, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'a10ancl4',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, a10ancl4'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! 10-day average canopy photosynthesis rate - c3 grasses
      call vec2arr(a10ancl3, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'a10ancl3',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, a10ancl3'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! 10-day average canopy scaling parameter - upper canopy
      call vec2arr(a10scalparamu, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'a10scalparamu',istart,icount,cdummy,ftime, &
                       tweight,tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, a10scalparamu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! 10-day average canopy scaling parameter - lower canopy
      call vec2arr(a10scalparaml, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'a10scalparaml',istart,icount,cdummy,ftime, &
                       tweight,tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, a10scalparaml'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! 10-day average daylight - upper canopy
      call vec2arr(a10daylightu, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'a10daylightu',istart,icount,cdummy,ftime, &
                       tweight,tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, a10daylightu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! 10-day average daylight - lower canopy
      call vec2arr(a10daylightl, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'a10daylightl',istart,icount,cdummy,ftime, &
                       tweight,tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, a10daylightl'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! drought-phenology trigger for trees
      call vec2arr(dropu, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'dropu',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, dropu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! drought-phenology trigger for shrubs
      call vec2arr(dropls, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'dropls',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, dropls'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! drought-phenology trigger for c4 grasses
      call vec2arr(dropl4, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'dropl4',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, dropl4'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! drought-phenology trigger for c3 grasses
      call vec2arr(dropl3, cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'dropl3',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, dropl3'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

!  LAI of upper canopy
      call vec2arr(lai(lbeg,2), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'laiu',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, laiu'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

!  LAI of lower canopy
      call vec2arr(lai(lbeg,1), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'lail',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, lail'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

! Summation variables
      call vec2arr(ayalit(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayalit',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayalit'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ayblit(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayblit',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayblit'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aycsoi(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aycsoi',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aycsoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ayco2root(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayco2root',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayco2root'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ayco2mic(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayco2mic',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayco2mic'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(yrleach(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'yrleach',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, yrleach'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ayneetot(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayneetot',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayneetot'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ayanlit(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayanlit',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayanlit'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aybnlit(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aybnlit',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aybnlit'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aynsoi(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aynsoi',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aynsoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ynleach(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ynleach',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ynleach'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ayprcp(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayprcp',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayprcp'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ayaet(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayaet',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayaet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aytrans(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aytrans',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aytrans'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aysrunoff(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aysrunoff',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aysrunoff'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aydrainage(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aydrainage',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aydrainage'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(dwtot(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'dwtot',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, dwtot'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(wtot(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'wtot',istart,icount,cdummy,ftime,tweight,tdate, &
                       istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, wtot'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aysolar(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aysolar',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aysolar'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ayreflect(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayreflect',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayreflect'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ayirup(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayirup',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayirup'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ayirdown(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayirdown',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayirdown'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aysens(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aysens',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aysens'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aylatent(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aylatent',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aylatent'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aywsoi(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aywsoi',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aywsoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aywisoi(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aywisoi',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aywisoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aytsoi(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aytsoi',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aytsoi'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ayvwc(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayvwc',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayvwc'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ayawc(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayawc',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayawc'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(firefac(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'firefac',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, firefac'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(ayrootbio(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'ayrootbio',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, ayrootbio'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aynmintot(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aynmintot',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aynmintot'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(aycmic(lbeg), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aycmic',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aycmic'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(xinwet(lbeg,1), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'janxinwet',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, janxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(xinwet(lbeg,2), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'febxinwet',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, febxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(xinwet(lbeg,3), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'marxinwet',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, marxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(xinwet(lbeg,4), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'aprxinwet',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, aprxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(xinwet(lbeg,5), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'mayxinwet',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, mayxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif
 
      call vec2arr(xinwet(lbeg,6), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'junxinwet',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, junxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(xinwet(lbeg,7), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'julxinwet',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, julxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(xinwet(lbeg,8), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'augxinwet',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, augxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(xinwet(lbeg,9), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'sepxinwet',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, sepxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(xinwet(lbeg,10), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'octxinwet',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, octxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(xinwet(lbeg,11), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'novxinwet',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, novxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      call vec2arr(xinwet(lbeg,12), cdummy)
      if (myid .eq. 0) then
         icount(3) = 1
         call writevar(filen,'decxinwet',istart,icount,cdummy,ftime,tweight, &
                       tdate,istat)
         if (istat .ne. 0) then
            write(*,*) 'ERROR in wrestart, decxinwet'
#ifdef CAMIBIS
            call endrun
#else /* CAMIBIS */
            stop
#endif /* CAMIBIS */
         endif
      endif

      if (myid .eq. 0) then
         open(unit=8, file=trim(outdir)//'/inland-restart_control.dat')
         write(8,*) iyear, imonthp
         close(8)
      endif
      return
end subroutine wrestart
