#include "inland_config.h"

#ifdef SINGLE_POINT_MODEL
#error "This subroutine should NOT be compiled for 0D IBIS model option."
#endif

! ies-io.f last update 9/9/98 Christine C. Molling, cmolling@facstaff.wisc.edu
! University of Wisconsin - Madison; Institute for Environmental Studies;
! Center for Climatic Research; Climate, People, and Environment Program
!
! You are free to change or distribute my code as long as you
! 1) acknowlege me, Christine C. Molling (cmolling@facstaff.wisc.edu)
! as the author of the original code and 
! 2) do not sell it.
! Of course if there is anything wrong with the code, or you somehow
! encounter damage to your reputation/wallet because of its use, you
! are forbidden to sue me or anyone else.
!
!     These subroutines can be used as a primary interface to the ies
! format netcdf files.  You can also use the slightly lower level functions
! found in ies.f or the low level netcdf commands (see the netcdf V3
! users guide).
!SUBROUTINE LIST:
! inifile - create a new file with dimensions and variables for
!  longitude, latitude, an optional 3rd real dimension, and time
!  Time must have units of days since a date!!!
! inifilec - create a new file with dimensions and variables for
!  longitude, latitude, a 3rd character-variable dimension, and time
!  Time must have units of days since a date!!!
! inivar - initialize a new variable
! endini - end initialization of file: sync file to disk, close file
! writevar - write a 2-, 3-, or 4-dimensional hyperslab of data
! readvar - read a 2-, 3-, or 4-dimensional hyperslab of data
!.....................................................................
! writevar - write a 2-, 3-, or 4-dimensional hyperslab of data
!.....................................................................
subroutine writevar(filen,varname,istart,icount,values,times,tweights,dates, &
                    ierror)
      implicit none

!INPUT
!     filen - character*(*) - file name to which to write data
!     varname - character*(*) - name of variable to which to write
!     istart - integer(*) - starting points along each dimension of
!      the variable, for example the 1st point a 4-d variable is (1,1,1,1) 
!      and the 3rd level and 2nd time step of a 4d variable is (1,1,3,2).
!     icount - integer(*) - number of points along each dimension to write,
!      for example, to write a single lat/lon grid to a 4-d variable,
!      icount would be (nlon,nlat,1,1).
!     values - real(*) - real values of the designated hyperslab
!     times - real(*) - time vector vector for those points written (ignored
!      if variable is 2-d).
!     tweights - real(*) - number of days in each time step in times (ignored
!      if variable is 2-d).
!     dates - character*10(*) - character labels for each time step in times,
!      last character should be a null (dates ignored if variable 2-d).
!OUTPUT
!     ierror - integer - error code = 0 if no error, < 0 if error occurred

!FIXME: These asterisks on var dimensions should be : to comform to fortran 90!
      character*(*) filen, varname
      character*10 dates(*)
      integer istart(*), icount(*), ierror
      real*8 values(*), times(*), tweights(*)

#ifdef GFORTRAN
#include <netcdf.inc>
#else /* GFORTRAN */
      include 'netcdf.inc'
#endif

      integer idies, idvar, ndims, ierr, idtime, idtw, iddate
      integer ist(2), ict(2)

      ierror = 0

!     Open file, but don't fail if already open
!     -----------------------------------------
      ierr = NF_OPEN(filen,NF_WRITE,idies)
      if (ierr .ne. NF_NOERR) then
         print *, 'Warning in writevar'
         print *, NF_STRERROR(ierr)
      end if

!     Get id of variable
!     ------------------
      ierr = NF_INQ_VARID(idies,varname,idvar)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in writevar'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if

!     Inquire number of dimensions
!     ----------------------------
      ierr = NF_INQ_VARNDIMS(idies,idvar,ndims)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in writevar'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if

!     Put variable
!     ------------
      ierr = NF_PUT_VARA_DOUBLE(idies,idvar,istart,icount,values)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in writevar'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if

!     Put time value(s), time weights, dates if necesary
!     --------------------------------------------------
      if (ndims .gt. 2) then
         ierr = NF_INQ_VARID(idies,'time',idtime)
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in writevar'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
         ierr = NF_PUT_VARA_DOUBLE(idies,idtime,istart(ndims),icount(ndims), &
                                   times)
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in writevar'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
         ierr = NF_INQ_VARID(idies,'time_weights',idtw)
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in writevar'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
         ierr = NF_PUT_VARA_DOUBLE(idies,idtw,istart(ndims),icount(ndims), &
                                   tweights)
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in writevar'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
         ierr = NF_INQ_VARID(idies,'date',iddate)
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in writevar'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
         ist(1)=1
         ist(2)=istart(ndims)
         ict(1)=10
         ict(2)=icount(ndims)
         ierr = NF_PUT_VARA_TEXT(idies,iddate,ist,ict,dates)
         if (ierr .ne. NF_NOERR) then
            print *, 'Error in writevar'
            print *, NF_STRERROR(ierr)
            ierror = -1
            return
         end if
      end if

!     Close file
!     ----------
      ierr = NF_CLOSE(idies)
      if (ierr .ne. NF_NOERR) then
         print *, 'Error in writevar'
         print *, NF_STRERROR(ierr)
         ierror = -1
         return
      end if
      return
end subroutine writevar
